"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module DisplayStyles
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AmbientOcclusion = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
/** Namespace containing types controlling how ambient occlusion should be drawn.
 * @public
 */
var AmbientOcclusion;
(function (AmbientOcclusion) {
    /** Describes the properties with which ambient occlusion should be drawn. These properties correspond to a horizon-based ambient occlusion approach. */
    class Settings {
        constructor(json) {
            if (undefined === json)
                json = {};
            this.bias = bentleyjs_core_1.JsonUtils.asDouble(json.bias, Settings._defaultBias);
            this.zLengthCap = bentleyjs_core_1.JsonUtils.asDouble(json.zLengthCap, Settings._defaultZLengthCap);
            this.maxDistance = bentleyjs_core_1.JsonUtils.asDouble(json.maxDistance, Settings._defaultMaxDistance);
            this.intensity = bentleyjs_core_1.JsonUtils.asDouble(json.intensity, Settings._defaultIntensity);
            this.texelStepSize = bentleyjs_core_1.JsonUtils.asDouble(json.texelStepSize, Settings._defaultTexelStepSize);
            this.blurDelta = bentleyjs_core_1.JsonUtils.asDouble(json.blurDelta, Settings._defaultBlurDelta);
            this.blurSigma = bentleyjs_core_1.JsonUtils.asDouble(json.blurSigma, Settings._defaultBlurSigma);
            this.blurTexelStepSize = bentleyjs_core_1.JsonUtils.asDouble(json.blurTexelStepSize, Settings._defaultBlurTexelStepSize);
        }
        static fromJSON(json) { return undefined !== json ? new Settings(json) : this.defaults; }
        toJSON() {
            return {
                bias: this.bias,
                zLengthCap: this.zLengthCap,
                maxDistance: this.maxDistance,
                intensity: this.intensity,
                texelStepSize: this.texelStepSize,
                blurDelta: this.blurDelta,
                blurSigma: this.blurSigma,
                blurTexelStepSize: this.blurTexelStepSize,
            };
        }
    }
    Settings._defaultBias = 0.25;
    Settings._defaultZLengthCap = 0.0025;
    Settings._defaultMaxDistance = 100.0;
    Settings._defaultIntensity = 1.0;
    Settings._defaultTexelStepSize = 1;
    Settings._defaultBlurDelta = 1.0;
    Settings._defaultBlurSigma = 2.0;
    Settings._defaultBlurTexelStepSize = 1.0;
    Settings.defaults = new Settings({});
    AmbientOcclusion.Settings = Settings;
})(AmbientOcclusion = exports.AmbientOcclusion || (exports.AmbientOcclusion = {}));
//# sourceMappingURL=AmbientOcclusion.js.map