"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module CloudStorage
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CloudStorageTileCache = void 0;
const CloudStorage_1 = require("./CloudStorage");
const IModelTileRpcInterface_1 = require("./rpc/IModelTileRpcInterface");
/** @beta */
class CloudStorageTileCache extends CloudStorage_1.CloudStorageCache {
    constructor() {
        super();
    }
    static getCache() {
        if (!CloudStorageTileCache._instance) {
            CloudStorageTileCache._instance = new CloudStorageTileCache();
        }
        return CloudStorageTileCache._instance;
    }
    supplyExpiryForContainerUrl(_id) {
        const expiry = new Date();
        const today = new Date().getDay();
        const rolloverDay = 6; // saturday
        expiry.setHours((rolloverDay - today) * 24);
        expiry.setHours(23);
        expiry.setMinutes(59);
        expiry.setSeconds(59);
        expiry.setMilliseconds(999);
        return expiry;
    }
    async obtainContainerUrl(id, descriptor) {
        const client = IModelTileRpcInterface_1.IModelTileRpcInterface.getClient();
        return client.getTileCacheContainerUrl(id.tokenProps, descriptor);
    }
    async instantiateResource(response) {
        const data = await response.arrayBuffer();
        if (!data.byteLength) {
            return undefined;
        }
        return new Uint8Array(data);
    }
    formContainerName(id) {
        return `${id.tokenProps.iModelId}`;
    }
    formResourceName(id) {
        const changeSetId = id.tokenProps.changeSetId || "first";
        const version = id.guid ? id.guid : changeSetId; // NB: id.guid can be null (backend) OR undefined (frontend) here...
        return `tiles/${id.treeId}/${version}/${id.contentId}`;
    }
    formContainerKey(id) {
        if (this.provider === CloudStorage_1.CloudStorageProvider.AliCloud) {
            return this.formContainerName(id) + this.formResourceName(id);
        }
        return super.formContainerKey(id);
    }
}
exports.CloudStorageTileCache = CloudStorageTileCache;
//# sourceMappingURL=CloudStorageTileCache.js.map