"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Rendering
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeatureIndex = exports.FeatureIndexType = exports.ColorIndex = exports.NonUniformColor = void 0;
const ColorDef_1 = require("./ColorDef");
/** @internal */
class NonUniformColor {
    constructor(colors, indices, hasAlpha) {
        this.colors = new Uint32Array(colors.buffer);
        this.indices = Uint16Array.from(indices);
        this.isOpaque = !hasAlpha;
    }
}
exports.NonUniformColor = NonUniformColor;
/** @internal */
class ColorIndex {
    constructor() { this._color = ColorDef_1.ColorDef.white; }
    get hasAlpha() { return !this._color.isOpaque; }
    get isUniform() { return this._color instanceof ColorDef_1.ColorDef; }
    get numColors() { return this.isUniform ? 1 : this.nonUniform.colors.length; }
    reset() { this._color = ColorDef_1.ColorDef.white; }
    get uniform() {
        return this.isUniform ? this._color : undefined;
    }
    initUniform(color) {
        this._color = typeof color === "number" ? ColorDef_1.ColorDef.fromJSON(color) : color;
    }
    get nonUniform() {
        return !this.isUniform ? this._color : undefined;
    }
    initNonUniform(colors, indices, hasAlpha) {
        this._color = new NonUniformColor(colors, indices, hasAlpha);
    }
}
exports.ColorIndex = ColorIndex;
/** @internal */
var FeatureIndexType;
(function (FeatureIndexType) {
    FeatureIndexType[FeatureIndexType["Empty"] = 0] = "Empty";
    FeatureIndexType[FeatureIndexType["Uniform"] = 1] = "Uniform";
    FeatureIndexType[FeatureIndexType["NonUniform"] = 2] = "NonUniform";
})(FeatureIndexType = exports.FeatureIndexType || (exports.FeatureIndexType = {}));
/** @internal */
class FeatureIndex {
    constructor() {
        this.type = FeatureIndexType.Empty;
        this.featureID = 0;
        this.reset();
    }
    get isUniform() { return FeatureIndexType.Uniform === this.type; }
    get isEmpty() { return FeatureIndexType.Empty === this.type; }
    reset() { this.type = FeatureIndexType.Empty; this.featureID = 0; this.featureIDs = undefined; }
}
exports.FeatureIndex = FeatureIndex;
//# sourceMappingURL=FeatureIndex.js.map