/** @packageDocumentation
 * @module Symbology
 */
/** The type of a font.
 * @public
 */
export declare enum FontType {
    TrueType = 1,
    Rsc = 2,
    Shx = 3
}
/** The properties of a Font. This includes a iModel local id, the font type, and the font name.
 * @public
 */
export interface FontProps {
    id: number;
    type: FontType;
    name: string;
}
/** The properties of a FontMap
 * @public
 */
export interface FontMapProps {
    fonts: FontProps[];
}
/** A FontMap holds the table of known fonts available in an iModel.
 * A font is referenced by an "id" that is local to the iModel. This table maps those local ids to a FontProps.
 * @public
 */
export declare class FontMap {
    readonly fonts: Map<number, FontProps>;
    constructor(props?: FontMapProps);
    addFonts(fonts: FontProps[]): void;
    toJSON(): FontMapProps;
    /** look up a font by name or number and return its FontProps */
    getFont(arg: string | number): FontProps | undefined;
}
//# sourceMappingURL=Fonts.d.ts.map