/** @packageDocumentation
 * @module iModels
 */
import { GeoServiceStatus } from "@bentley/bentleyjs-core";
import { XYZProps } from "@bentley/geometry-core";
/** @public */
export declare enum GeoCoordStatus {
    Success = 0,
    NoGCSDefined = 100,
    OutOfUsefulRange = 1,
    OutOfMathematicalDomain = 2,
    NoDatumConverter = 25,
    VerticalDatumConvertError = 26,
    CSMapError = 4096,
    Pending = -41556
}
/** Maps a GeoCoordStatus to the equivalent GeoServiceStatus.
 * @public
 */
export declare function mapToGeoServiceStatus(s: GeoCoordStatus): GeoServiceStatus;
/** Information required to request conversion of an array of Geographic coordinates (Longitude/Latitude) to iModel coordinates
 * @beta
 */
export interface IModelCoordinatesRequestProps {
    sourceDatum: string;
    geoCoords: XYZProps[];
}
/** Information returned from a request to convert an array of Geographic coordinates (Longitude/Latitude) to iModel coordinates
 * @beta
 */
export interface PointWithStatus {
    p: XYZProps;
    s: GeoCoordStatus;
}
/** @beta */
export interface IModelCoordinatesResponseProps {
    iModelCoords: PointWithStatus[];
    fromCache: number;
}
/** Information required to request conversion of an array of iModel coordinates to Geographic Coordinates (longitude and latitude)
 * @beta
 */
export interface GeoCoordinatesRequestProps {
    targetDatum: string;
    iModelCoords: XYZProps[];
}
/** Information returned from a request to convert an array of iModel coordinates to Geographic Coordinates (longitude and latitude)
 * @beta
 */
export interface GeoCoordinatesResponseProps {
    geoCoords: PointWithStatus[];
    fromCache: number;
}
//# sourceMappingURL=GeoCoordinateServices.d.ts.map