"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module iModels
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapToGeoServiceStatus = exports.GeoCoordStatus = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
/** @public */
var GeoCoordStatus;
(function (GeoCoordStatus) {
    GeoCoordStatus[GeoCoordStatus["Success"] = 0] = "Success";
    GeoCoordStatus[GeoCoordStatus["NoGCSDefined"] = 100] = "NoGCSDefined";
    GeoCoordStatus[GeoCoordStatus["OutOfUsefulRange"] = 1] = "OutOfUsefulRange";
    GeoCoordStatus[GeoCoordStatus["OutOfMathematicalDomain"] = 2] = "OutOfMathematicalDomain";
    GeoCoordStatus[GeoCoordStatus["NoDatumConverter"] = 25] = "NoDatumConverter";
    GeoCoordStatus[GeoCoordStatus["VerticalDatumConvertError"] = 26] = "VerticalDatumConvertError";
    GeoCoordStatus[GeoCoordStatus["CSMapError"] = 4096] = "CSMapError";
    GeoCoordStatus[GeoCoordStatus["Pending"] = -41556] = "Pending";
})(GeoCoordStatus = exports.GeoCoordStatus || (exports.GeoCoordStatus = {}));
/** Maps a GeoCoordStatus to the equivalent GeoServiceStatus.
 * @public
 */
function mapToGeoServiceStatus(s) {
    switch (s) {
        case GeoCoordStatus.Success: return bentleyjs_core_1.GeoServiceStatus.Success;
        case GeoCoordStatus.NoGCSDefined: return bentleyjs_core_1.GeoServiceStatus.NoGeoLocation;
        case GeoCoordStatus.OutOfUsefulRange: return bentleyjs_core_1.GeoServiceStatus.OutOfUsefulRange;
        case GeoCoordStatus.OutOfMathematicalDomain: return bentleyjs_core_1.GeoServiceStatus.OutOfMathematicalDomain;
        case GeoCoordStatus.NoDatumConverter: return bentleyjs_core_1.GeoServiceStatus.NoDatumConverter;
        case GeoCoordStatus.VerticalDatumConvertError: return bentleyjs_core_1.GeoServiceStatus.VerticalDatumConvertError;
        case GeoCoordStatus.CSMapError: return bentleyjs_core_1.GeoServiceStatus.CSMapError;
        case GeoCoordStatus.Pending: return bentleyjs_core_1.GeoServiceStatus.Pending;
        default:
            throw new Error("GeoCoordStatus -> GeoServiceStatus - Missing enum conversion");
    }
}
exports.mapToGeoServiceStatus = mapToGeoServiceStatus;
//# sourceMappingURL=GeoCoordinateServices.js.map