/** @packageDocumentation
 * @module DisplayStyles
 */
import { ColorDef, ColorDefProps } from "./ColorDef";
import { Gradient } from "./Gradient";
/** JSON representation of a [[GroundPlane]].
 * @public
 */
export interface GroundPlaneProps {
    /** Whether the ground plane should be displayed. Defaults to false. */
    display?: boolean;
    /** The Z height at which to draw the ground plane. */
    elevation?: number;
    /** The color in which to draw the ground plane when viewed from above. */
    aboveColor?: ColorDefProps;
    /** The color in which to draw the ground plane when viewed from below. */
    belowColor?: ColorDefProps;
}
/** A circle drawn at a Z elevation, whose diameter is the the XY diagonal of the project extents, used to represent the ground as a reference point within a spatial view.
 * @public
 */
export declare class GroundPlane {
    /** Whether the ground plane should be displayed. */
    display: boolean;
    /** The Z height at which to draw the plane. */
    elevation: number;
    /** The color in which to draw the ground plane when viewed from above. */
    aboveColor: ColorDef;
    /** The color in which to draw the ground plane when viewed from below. */
    belowColor: ColorDef;
    private _aboveSymb?;
    private _belowSymb?;
    constructor(ground?: GroundPlaneProps);
    toJSON(): GroundPlaneProps;
    /** Returns and locally stores gradient symbology for the ground plane texture depending on whether we are looking from above or below.
     * Will store the ground colors used in the optional ColorDef array provided.
     * @internal
     */
    getGroundPlaneGradient(aboveGround: boolean): Gradient.Symb;
}
//# sourceMappingURL=GroundPlane.d.ts.map