/** @packageDocumentation
 * @module iModels
 */
import { AuthStatus, BentleyError, BentleyStatus, BriefcaseStatus, ChangeSetStatus, DbResult, GetMetaDataFunction, IModelStatus, LogFunction, RepositoryStatus, RpcInterfaceStatus } from "@bentley/bentleyjs-core";
export { BentleyStatus, BentleyError, IModelStatus, BriefcaseStatus, GetMetaDataFunction, LogFunction, DbResult, AuthStatus, RepositoryStatus, ChangeSetStatus, RpcInterfaceStatus } from "@bentley/bentleyjs-core";
/** The error type thrown by this module. See [[IModelStatus]] for `errorNumber` values.
 * @public
 */
export declare class IModelError extends BentleyError {
    constructor(errorNumber: number | IModelStatus | DbResult | BentleyStatus | BriefcaseStatus | RepositoryStatus | ChangeSetStatus | RpcInterfaceStatus | AuthStatus, message: string, log?: LogFunction, category?: string, getMetaData?: GetMetaDataFunction);
}
/** @public */
export declare class ServerError extends IModelError {
    constructor(errorNumber: number, message: string, log?: LogFunction);
}
/** @public */
export declare class ServerTimeoutError extends ServerError {
    constructor(message: string, log?: LogFunction);
}
/** @public */
export declare class BackendError extends IModelError {
    constructor(errorNumber: number, name: string, message: string, log?: LogFunction, category?: string, getMetaData?: GetMetaDataFunction);
}
/**
 * Channel constraint error
 * @alpha
 */
export declare class ChannelConstraintError extends IModelError {
    constructor(message: string, log?: LogFunction, category?: string, getMetaData?: GetMetaDataFunction);
}
/** Intended for API "no content" semantics where the error case should not trigger application failure monitoring systems.
 * @public
 */
export declare class NoContentError extends IModelError {
    constructor();
}
//# sourceMappingURL=IModelError.d.ts.map