"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module iModels
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.NoContentError = exports.ChannelConstraintError = exports.BackendError = exports.ServerTimeoutError = exports.ServerError = exports.IModelError = exports.RpcInterfaceStatus = exports.ChangeSetStatus = exports.RepositoryStatus = exports.AuthStatus = exports.DbResult = exports.BriefcaseStatus = exports.IModelStatus = exports.BentleyError = exports.BentleyStatus = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
var bentleyjs_core_2 = require("@bentley/bentleyjs-core");
Object.defineProperty(exports, "BentleyStatus", { enumerable: true, get: function () { return bentleyjs_core_2.BentleyStatus; } });
Object.defineProperty(exports, "BentleyError", { enumerable: true, get: function () { return bentleyjs_core_2.BentleyError; } });
Object.defineProperty(exports, "IModelStatus", { enumerable: true, get: function () { return bentleyjs_core_2.IModelStatus; } });
Object.defineProperty(exports, "BriefcaseStatus", { enumerable: true, get: function () { return bentleyjs_core_2.BriefcaseStatus; } });
Object.defineProperty(exports, "DbResult", { enumerable: true, get: function () { return bentleyjs_core_2.DbResult; } });
Object.defineProperty(exports, "AuthStatus", { enumerable: true, get: function () { return bentleyjs_core_2.AuthStatus; } });
Object.defineProperty(exports, "RepositoryStatus", { enumerable: true, get: function () { return bentleyjs_core_2.RepositoryStatus; } });
Object.defineProperty(exports, "ChangeSetStatus", { enumerable: true, get: function () { return bentleyjs_core_2.ChangeSetStatus; } });
Object.defineProperty(exports, "RpcInterfaceStatus", { enumerable: true, get: function () { return bentleyjs_core_2.RpcInterfaceStatus; } });
/** The error type thrown by this module. See [[IModelStatus]] for `errorNumber` values.
 * @public
 */
class IModelError extends bentleyjs_core_1.BentleyError {
    constructor(errorNumber, message, log, category, getMetaData) {
        super(errorNumber, message, log, category, getMetaData);
    }
}
exports.IModelError = IModelError;
/** @public */
class ServerError extends IModelError {
    constructor(errorNumber, message, log) {
        super(errorNumber, message, log);
        this.name = `Server error (${errorNumber})`;
    }
}
exports.ServerError = ServerError;
/** @public */
class ServerTimeoutError extends ServerError {
    constructor(message, log) {
        super(bentleyjs_core_1.IModelStatus.ServerTimeout, message, log);
        this.name = "Server timeout error";
    }
}
exports.ServerTimeoutError = ServerTimeoutError;
/** @public */
class BackendError extends IModelError {
    constructor(errorNumber, name, message, log, category, getMetaData) {
        super(errorNumber, message, log, category, getMetaData);
        this.name = name;
    }
}
exports.BackendError = BackendError;
/**
 * Channel constraint error
 * @alpha
 */
class ChannelConstraintError extends IModelError {
    constructor(message, log, category, getMetaData) {
        super(bentleyjs_core_1.RepositoryStatus.ChannelConstraintViolation, message, log, category, getMetaData);
    }
}
exports.ChannelConstraintError = ChannelConstraintError;
/** Intended for API "no content" semantics where the error case should not trigger application failure monitoring systems.
 * @public
 */
class NoContentError extends IModelError {
    constructor() {
        super(bentleyjs_core_1.IModelStatus.NoContent, "No Content");
    }
}
exports.NoContentError = NoContentError;
//# sourceMappingURL=IModelError.js.map