"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Symbology
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LinePixels = void 0;
/** Enumerates the available patterns for drawing patterned lines.
 * Each is a 32-bit pattern in which each bit specifies the on- or off-state of a pixel along the line. The pattern repeats along the length of the entire line.
 * @public
 */
var LinePixels;
(function (LinePixels) {
    /** A solid line. */
    LinePixels[LinePixels["Solid"] = 0] = "Solid";
    /** A solid line. */
    LinePixels[LinePixels["Code0"] = 0] = "Code0";
    /** 1 lit pixel followed by 7 unlit pixels: =&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;=&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;= */
    LinePixels[LinePixels["Code1"] = 2155905152] = "Code1";
    /** 5 lit pixels followed by 3 unlit pixels: =====&nbsp;&nbsp;&nbsp;=====&nbsp;&nbsp;&nbsp;===== */
    LinePixels[LinePixels["Code2"] = 4177066232] = "Code2";
    /** 11 lit pixels followed by 5 unlit pixels: ===========&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;=========== */
    LinePixels[LinePixels["Code3"] = 4292935648] = "Code3";
    /** 7 lit pixels followed by 4 unlit pixels followed by 1 lit pixel followed by 1 lit pixel: =======&nbsp;&nbsp;&nbsp;&nbsp;=&nbsp;&nbsp;&nbsp;&nbsp;=======&nbsp;&nbsp;&nbsp;&nbsp;= */
    LinePixels[LinePixels["Code4"] = 4262526480] = "Code4";
    /** 3 lit pixels followed by 5 unlit pixels: ===&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;===&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;=== */
    LinePixels[LinePixels["Code5"] = 3772834016] = "Code5";
    /** 5 lit pixels followed by 3 unlit followed by 1 lit followed by 3 unlit followed by 1 lit followed by 3 unlit: =====&nbsp;&nbsp;&nbsp;=&nbsp;&nbsp;&nbsp;=&nbsp;&nbsp;&nbsp;===== */
    LinePixels[LinePixels["Code6"] = 4169726088] = "Code6";
    /** 8 lit pixels followed by 3 unlit followed by 2 lit followed by 3 unlit: ========&nbsp;&nbsp;&nbsp;==&nbsp;&nbsp;&nbsp;======== */
    LinePixels[LinePixels["Code7"] = 4279828248] = "Code7";
    /** 2 lit pixels followed by 2 unlit pixels - default style for drawing hidden edges: ==&nbsp;&nbsp;==&nbsp;&nbsp;==&nbsp;&nbsp;== */
    LinePixels[LinePixels["HiddenLine"] = 3435973836] = "HiddenLine";
    /** Barely visible - 1 lit pixel followed by 31 unlit pixels. */
    LinePixels[LinePixels["Invisible"] = 1] = "Invisible";
    /** Indicates no valid line style or none specified, depending on context. */
    LinePixels[LinePixels["Invalid"] = -1] = "Invalid";
})(LinePixels = exports.LinePixels || (exports.LinePixels = {}));
//# sourceMappingURL=LinePixels.js.map