/** @packageDocumentation
 * @module DisplayStyles
 */
import { BackgroundMapProps } from "./BackgroundMapSettings";
import { ColorDef, ColorDefProps } from "./ColorDef";
import { MapLayerProps, MapLayerSettings } from "./MapLayerSettings";
/** The JSON representation of base layer properties -- these can be represented by either a full map layer or a simple color.
 * @beta
 */
export declare type BaseLayerProps = MapLayerProps | ColorDefProps;
/** The JSON representation of the map imagery.  Map imagery include the specification for the base layer (which was originally
 * represented by [[BackgroundMapProps.providerName]]  && [[BackgroundMapProps.providerData]]) and additional map layers.
 * In earlier versions only a background map was supported as specified by the providerName and mapType members of [[BackgroundMapSettings]] object.
 * In order to provide backward compatibility the original [[BackgroundMapSettings]] are synchronized with the [[MapImagerySettings]] base layer as long as
 * the settings are compatible.
 * @beta
 */
export interface MapImageryProps {
    backgroundBase?: BaseLayerProps;
    backgroundLayers?: MapLayerProps[];
    overlayLayers?: MapLayerProps[];
}
/** Normalized representation of base layer properties -- these can be represented by either a full map layer or a simple color.
 * @beta
 */
export declare type BaseLayerSettings = MapLayerSettings | ColorDef;
/** Provides access to the map imagery settings (Base and layers).
 * In earlier versions only a background map was supported as specified by the providerName and mapType members of [[BackgroundMapSettings]] object.
 * In order to provide backward compatibility the original [[BackgroundMapSettings]] are synchronized with the [[MapImagerySettings]] base layer as long as
 * the settings are compatible.
 * @beta
 */
export declare class MapImagerySettings {
    private _backgroundBase;
    private _backgroundLayers;
    private _overlayLayers;
    private constructor();
    /** The settings for the base layer.
     *  @note If changing the base provider it is currently necessary to also update the background map settings.
     */
    get backgroundBase(): BaseLayerSettings;
    set backgroundBase(base: BaseLayerSettings);
    get backgroundLayers(): MapLayerSettings[];
    get overlayLayers(): MapLayerSettings[];
    /** Return base transparency as a number between 0 and 1.
     * @internal
     */
    get baseTransparency(): number;
    /** Construct from JSON, performing validation and applying default values for undefined fields. */
    static fromJSON(imageryJson?: MapImageryProps, mapProps?: BackgroundMapProps): MapImagerySettings;
    toJSON(): MapImageryProps;
}
//# sourceMappingURL=MapImagerySettings.d.ts.map