/** @packageDocumentation
 * @module ECSQL
 */
/** The desired ECSql query quota constraint. It is not guaranteed exactly but will be met as accurately as possible as long as it narrows the constraints imposed by the backend.
 * @public
 */
export interface QueryQuota {
    /** Maximum time in seconds after which query will be stopped */
    maxTimeAllowed?: number;
    /** Maximum size of result in bytes after which query will be stopped */
    maxMemoryAllowed?: number;
}
/** ECSql query subset specification
 * @public
 */
export interface QueryLimit {
    /** Maximum rows allowed to be returned */
    maxRowAllowed?: number;
    /** If set number of rows to skip before returning results */
    startRowOffset?: number;
}
/** Queue priority for query and its not guaranteed
 * @public
 */
export declare enum QueryPriority {
    Low = 0,
    Normal = 1,
    High = 2
}
/** State of query operations
 * @public
 */
export declare enum QueryResponseStatus {
    Partial = 3,
    Done = 2,
    Error = 5,
    Timeout = 4,
    PostError = 6,
    Cancelled = 7
}
/** Result of a query. Its not intended to be used directly by client
 * @public
 */
export interface QueryResponse {
    rows: any[];
    status: QueryResponseStatus;
}
//# sourceMappingURL=Paging.d.ts.map