/** @packageDocumentation
 * @module Rendering
 */
import { OctEncodedNormalPair } from "./OctEncodedNormal";
/** @internal */
export declare enum PolylineTypeFlags {
    Normal = 0,
    Edge = 1,
    Outline = 2
}
/** Flags describing a polyline. A polyline may represent a continuous line string, or a set of discrete points.
 * @internal
 */
export declare class PolylineFlags {
    isDisjoint: boolean;
    isPlanar: boolean;
    is2d: boolean;
    type: PolylineTypeFlags;
    constructor(is2d?: boolean, isPlanar?: boolean, isDisjoint?: boolean, type?: PolylineTypeFlags);
    clone(): PolylineFlags;
    /** Create a PolylineFlags from a serialized numeric representation. */
    static unpack(value: number): PolylineFlags;
    initDefaults(): void;
    get isOutlineEdge(): boolean;
    get isNormalEdge(): boolean;
    get isAnyEdge(): boolean;
    setIsNormalEdge(): void;
    setIsOutlineEdge(): void;
    /** Convert these flags to a numeric representation for serialization. */
    pack(): number;
    equals(other: PolylineFlags): boolean;
}
/** @internal */
export declare class PolylineData {
    vertIndices: number[];
    numIndices: number;
    constructor(vertIndices?: number[], numIndices?: number);
    get isValid(): boolean;
    reset(): void;
    init(polyline: MeshPolyline): boolean;
}
/** @internal */
export declare class MeshPolyline {
    readonly indices: number[];
    constructor(indices?: number[]);
    addIndex(index: number): void;
    clear(): void;
}
/** @internal */
export declare class MeshPolylineList extends Array<MeshPolyline> {
    constructor(...args: MeshPolyline[]);
}
/** @internal */
export declare class MeshEdge {
    indices: number[];
    constructor(index0?: number, index1?: number);
    compareTo(other: MeshEdge): number;
}
/** @internal */
export declare class MeshEdges {
    visible: MeshEdge[];
    silhouette: MeshEdge[];
    polylines: MeshPolylineList;
    silhouetteNormals: OctEncodedNormalPair[];
    constructor();
}
/** @internal */
export declare class EdgeArgs {
    edges?: MeshEdge[];
    init(meshEdges?: MeshEdges): boolean;
    clear(): void;
    get isValid(): boolean;
    get numEdges(): number;
}
/** @internal */
export declare class SilhouetteEdgeArgs extends EdgeArgs {
    normals?: OctEncodedNormalPair[];
    init(meshEdges?: MeshEdges): boolean;
    clear(): void;
}
/** @internal */
export declare class PolylineEdgeArgs {
    lines?: PolylineData[];
    constructor(lines?: PolylineData[]);
    init(lines?: PolylineData[]): boolean;
    get numLines(): number;
    get isValid(): boolean;
    clear(): void;
}
//# sourceMappingURL=Render.d.ts.map