/** @packageDocumentation
 * @module Symbology
 */
import { ColorDef } from "./ColorDef";
/** JSON representation of an [[RgbColor]], with each component an integer in the range [0, 255].
 * @public
 */
export interface RgbColorProps {
    r: number;
    g: number;
    b: number;
}
/** An immutable representation of a color with red, green, and blue components each in the integer range [0, 255].
 * @public
 */
export declare class RgbColor {
    readonly r: number;
    readonly g: number;
    readonly b: number;
    /** Constructs from red, green, and blue components.
     * @param r Red
     * @param g Green
     * @param b Blue
     */
    constructor(r: number, g: number, b: number);
    /** Constructs from the red, green, and blue components of a ColorDef. The transparency component is ignored. */
    static fromColorDef(colorDef: ColorDef): RgbColor;
    /** Converts this RgbColor to a ColorDef.
     * @param transparency Value to use for the transparency component of the ColorDef.
     * @param out If defined, this ColorDef will be modified in-place and returned; otherwise a new ColorDef will be allocated.
     * @returns A ColorDef with RGB components equivalent to those of this RgbColor and transparency component as specified.
     */
    toColorDef(transparency?: number): ColorDef;
    toJSON(): RgbColorProps;
    static fromJSON(json: RgbColorProps | undefined): RgbColor;
    equals(rhs: RgbColor): boolean;
}
//# sourceMappingURL=RgbColor.d.ts.map