/** @packageDocumentation
 * @module Utils
 */
import { Vector3d } from "@bentley/geometry-core";
import { Cartographic } from "./geometry/Cartographic";
/** @public
 * calculate solar angles (in radians) based at a given date/time and cartographic location.
 */
export declare function calculateSolarAngles(date: Date, location: Cartographic): {
    azimuth: number;
    elevation: number;
};
/** @public
 * calculate solar direction based at a given date/time and cartpgrphic location.
 */
export declare function calculateSolarDirection(date: Date, location: Cartographic): Vector3d;
/** @public
 * calculate solar direction corresponding to the given azimuth and elevation (altitude) angles in degrees.
 */
export declare function calculateSolarDirectionFromAngles(azimuthElevation: {
    azimuth: number;
    elevation: number;
}): Vector3d;
/** @public
 * calculate solar sunrise or sunset for a given day and cartographic location.
 */
export declare function calculateSunriseOrSunset(date: Date, location: Cartographic, sunrise: boolean): Date;
//# sourceMappingURL=SolarCalculate.d.ts.map