/** @packageDocumentation
 * @module DisplayStyles
 */
import { ColorDefProps } from "./ColorDef";
import { RgbColor } from "./RgbColor";
/** JSON representation of [[SolarShadowSettings]].
 * @public
 */
export interface SolarShadowSettingsProps {
    /** Shadow color. Default: [[ColorByName.grey]]. */
    color?: ColorDefProps;
    /** @internal */
    bias?: number;
}
/** Settings controlling display of solar shadows for a [[DisplayStyle3dSettings]].
 * Solar shadows are imposed as a color scaling on geometry occluded from solar lighting.
 * @public
 */
export declare class SolarShadowSettings {
    /** Shadow color. */
    readonly color: RgbColor;
    /** @internal */
    readonly bias: number;
    private constructor();
    static defaults: SolarShadowSettings;
    static fromJSON(props?: SolarShadowSettingsProps): SolarShadowSettings;
    toJSON(): SolarShadowSettingsProps | undefined;
    equals(rhs: SolarShadowSettings): boolean;
    /** Create a copy of these settings.
     * @param changedProps Any property explicitly defined will be overridden in the copy.
     * @returns A settings object equivalent to this one except for any properties explicitly overridden by `changedProps`.
     */
    clone(changedProps?: SolarShadowSettingsProps): SolarShadowSettings;
}
//# sourceMappingURL=SolarShadows.d.ts.map