"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module iModels
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TxnAction = void 0;
/** Describes the types of actions associated with [Txns]($docs/learning/InteractiveEditing.md).
 * @public
 */
var TxnAction;
(function (TxnAction) {
    /** Not currently processing anything. */
    TxnAction[TxnAction["None"] = 0] = "None";
    /** Processing a commit initiated by a call to [IModelDb.saveChanges]($backend) or [BriefcaseConnection.saveChanges]($frontend). */
    TxnAction[TxnAction["Commit"] = 1] = "Commit";
    /** Abandoning the current Txn, e.g., via [IModelDb.abandonChanges]($backend). */
    TxnAction[TxnAction["Abandon"] = 2] = "Abandon";
    /** Reversing a previously-committed changeset, e.g., via [TxnManager.reverseTxns]($backend) [BriefcaseTxns.reverseTxns]($frontend). */
    TxnAction[TxnAction["Reverse"] = 3] = "Reverse";
    /** Reinstating a previously reversed changeset, e.g., via [TxnManager.reinstateTxn]($backend) or [BriefcaseTxns.reinstateTxn]($frontend). */
    TxnAction[TxnAction["Reinstate"] = 4] = "Reinstate";
    /** Merging a changeset produced by a different briefcase, e.g., via [BriefcaseDb.pullAndMergeChanges]($backend) or [BriefcaseConnection.pullAndMergeChanges]($frontend). */
    TxnAction[TxnAction["Merge"] = 5] = "Merge";
})(TxnAction = exports.TxnAction || (exports.TxnAction = {}));
//# sourceMappingURL=TxnAction.js.map