/** @packageDocumentation
 * @module DisplayStyles
 */
/** JSON representation of a [[WhiteOnWhiteReversalSettings]].
 * @public
 */
export interface WhiteOnWhiteReversalProps {
    /** Default: false.
     * @see [[WhiteOnWhiteReversalSettings.ignoreBackgroundColor]].
     */
    ignoreBackgroundColor?: boolean;
}
/** As part of a [[DisplayStyleSettings]], controls how white-on-white reversal is applied to make white geometry more
 * visible in the view.
 * By default, pure white geometry is displayed as black instead if the [[DisplayStyleSettings.backgroundColor]] is also pure white.
 * These settings are only applied if the display style's [[ViewFlags.whiteOnWhiteReversal]] flag is enabled.
 * @see [[DisplayStyleSettings.whiteOnWhiteReversal]] to change these settings for a display style.
 * @public
 */
export declare class WhiteOnWhiteReversalSettings {
    /** If true, white-on-white reversal ignores the display style's background color; otherwise, white-on-white reversal applies only
     * if the background color is pure white.
     * @see [[DisplayStyleSettings.backgroundColor]] to change the background color.
     */
    readonly ignoreBackgroundColor: boolean;
    private constructor();
    private static _noIgnore;
    private static _ignore;
    /** Create from JSON representation. */
    static fromJSON(props?: WhiteOnWhiteReversalProps): WhiteOnWhiteReversalSettings;
    /** Convert to JSON representation. The JSON representation is `undefined` if these settings match the defaults. */
    toJSON(): WhiteOnWhiteReversalProps | undefined;
    /** Returns true if `this` is equivalent to `other`. */
    equals(other: WhiteOnWhiteReversalSettings): boolean;
}
//# sourceMappingURL=WhiteOnWhiteReversalSettings.d.ts.map