"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Geometry
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.BoundingSphere = void 0;
const geometry_core_1 = require("@bentley/geometry-core");
/** Represents a bounding sphere.  Optional optimization for FrustumPlane containment test.
 * @public
 */
class BoundingSphere {
    constructor(center, radius) { this.center = center ? center : geometry_core_1.Point3d.createZero(); this.radius = undefined === radius ? 0.0 : radius; }
    init(center, radius) { this.center = center; this.radius = radius; }
    transformBy(transform, result) {
        transform.multiplyPoint3d(this.center, result.center);
        result.radius = this.radius * Math.max(transform.matrix.columnXMagnitude(), Math.max(transform.matrix.columnYMagnitude(), (transform.matrix.columnZMagnitude())));
        return result;
    }
}
exports.BoundingSphere = BoundingSphere;
//# sourceMappingURL=BoundingSphere.js.map