/** @packageDocumentation
 * @module Serialization
 */
import { flatbuffers } from "flatbuffers";
export declare namespace EGFBAccessors {
    /**
     * @enum {number}
     */
    enum GradientMode {
        None = 0,
        Linear = 1,
        Curved = 2,
        Cylindrical = 3,
        Spherical = 4,
        Hemispherical = 5,
        Thematic = 6
    }
    /**
     * @enum {number}
     */
    enum BoundaryType {
        None = 0,
        Open = 1,
        Closed = 2
    }
    /**
     * @enum {number}
     */
    enum FillDisplay {
        None = 0,
        ByView = 1,
        Always = 2,
        Blanking = 3
    }
    /**
     * @enum {number}
     */
    enum GeometryClass {
        Primary = 0,
        Construction = 1,
        Dimension = 2,
        Pattern = 3
    }
    /**
     * @enum {number}
     */
    enum BRepType {
        Solid = 0,
        Sheet = 1,
        Wire = 2
    }
    /**
     * @constructor
     */
    class DPoint3d {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns DPoint3d
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): DPoint3d;
        /**
         * @returns number
         */
        x(): number;
        /**
         * @returns number
         */
        y(): number;
        /**
         * @returns number
         */
        z(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number x
         * @param number y
         * @param number z
         * @returns flatbuffers.Offset
         */
        static createDPoint3d(builder: flatbuffers.Builder, x: number, y: number, z: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class DPoint2d {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns DPoint2d
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): DPoint2d;
        /**
         * @returns number
         */
        x(): number;
        /**
         * @returns number
         */
        y(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number x
         * @param number y
         * @returns flatbuffers.Offset
         */
        static createDPoint2d(builder: flatbuffers.Builder, x: number, y: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class DVec3d {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns DVec3d
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): DVec3d;
        /**
         * @returns number
         */
        x(): number;
        /**
         * @returns number
         */
        y(): number;
        /**
         * @returns number
         */
        z(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number x
         * @param number y
         * @param number z
         * @returns flatbuffers.Offset
         */
        static createDVec3d(builder: flatbuffers.Builder, x: number, y: number, z: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class RotMatrix {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns RotMatrix
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): RotMatrix;
        /**
         * @returns number
         */
        x00(): number;
        /**
         * @returns number
         */
        x01(): number;
        /**
         * @returns number
         */
        x02(): number;
        /**
         * @returns number
         */
        x10(): number;
        /**
         * @returns number
         */
        x11(): number;
        /**
         * @returns number
         */
        x12(): number;
        /**
         * @returns number
         */
        x20(): number;
        /**
         * @returns number
         */
        x21(): number;
        /**
         * @returns number
         */
        x22(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number x00
         * @param number x01
         * @param number x02
         * @param number x10
         * @param number x11
         * @param number x12
         * @param number x20
         * @param number x21
         * @param number x22
         * @returns flatbuffers.Offset
         */
        static createRotMatrix(builder: flatbuffers.Builder, x00: number, x01: number, x02: number, x10: number, x11: number, x12: number, x20: number, x21: number, x22: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class Transform {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns Transform
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): Transform;
        /**
         * @returns number
         */
        x00(): number;
        /**
         * @returns number
         */
        x01(): number;
        /**
         * @returns number
         */
        x02(): number;
        /**
         * @returns number
         */
        tx(): number;
        /**
         * @returns number
         */
        x10(): number;
        /**
         * @returns number
         */
        x11(): number;
        /**
         * @returns number
         */
        x12(): number;
        /**
         * @returns number
         */
        ty(): number;
        /**
         * @returns number
         */
        x20(): number;
        /**
         * @returns number
         */
        x21(): number;
        /**
         * @returns number
         */
        x22(): number;
        /**
         * @returns number
         */
        tz(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number x00
         * @param number x01
         * @param number x02
         * @param number tx
         * @param number x10
         * @param number x11
         * @param number x12
         * @param number ty
         * @param number x20
         * @param number x21
         * @param number x22
         * @param number tz
         * @returns flatbuffers.Offset
         */
        static createTransform(builder: flatbuffers.Builder, x00: number, x01: number, x02: number, tx: number, x10: number, x11: number, x12: number, ty: number, x20: number, x21: number, x22: number, tz: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class Trans2x3 {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns Trans2x3
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): Trans2x3;
        /**
         * @returns number
         */
        x00(): number;
        /**
         * @returns number
         */
        x01(): number;
        /**
         * @returns number
         */
        tx(): number;
        /**
         * @returns number
         */
        y00(): number;
        /**
         * @returns number
         */
        y01(): number;
        /**
         * @returns number
         */
        ty(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number x00
         * @param number x01
         * @param number tx
         * @param number y00
         * @param number y01
         * @param number ty
         * @returns flatbuffers.Offset
         */
        static createTrans2x3(builder: flatbuffers.Builder, x00: number, x01: number, tx: number, y00: number, y01: number, ty: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class FaceSymbology {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns FaceSymbology
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): FaceSymbology;
        /**
         * @returns number
         */
        useColor(): number;
        /**
         * @returns number
         */
        useMaterial(): number;
        /**
         * @returns number
         */
        color(): number;
        /**
         * @returns flatbuffers.Long
         */
        materialId(): flatbuffers.Long;
        /**
         * @returns number
         */
        transparency(): number;
        /**
         * @param DPoint2d= obj
         * @returns DPoint2d|null
         */
        uv(obj?: DPoint2d): DPoint2d | null;
        /**
         * @param flatbuffers.Builder builder
         * @param number useColor
         * @param number useMaterial
         * @param number color
         * @param flatbuffers.Long materialId
         * @param number transparency
         * @param number uv_x
         * @param number uv_y
         * @returns flatbuffers.Offset
         */
        static createFaceSymbology(builder: flatbuffers.Builder, useColor: number, useMaterial: number, color: number, materialId: flatbuffers.Long, transparency: number, uv_x: number, uv_y: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class FaceSymbologyIndex {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns FaceSymbologyIndex
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): FaceSymbologyIndex;
        /**
         * @returns number
         */
        faceIndex(): number;
        /**
         * @returns number
         */
        symbIndex(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number faceIndex
         * @param number symbIndex
         * @returns flatbuffers.Offset
         */
        static createFaceSymbologyIndex(builder: flatbuffers.Builder, faceIndex: number, symbIndex: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class DRange1d {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns DRange1d
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): DRange1d;
        /**
         * @returns number
         */
        low(): number;
        /**
         * @returns number
         */
        high(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number low
         * @param number high
         * @returns flatbuffers.Offset
         */
        static createDRange1d(builder: flatbuffers.Builder, low: number, high: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class PointPrimitive {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns PointPrimitive
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): PointPrimitive;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param PointPrimitive= obj
         * @returns PointPrimitive
         */
        static getRootAsPointPrimitive(bb: flatbuffers.ByteBuffer, obj?: PointPrimitive): PointPrimitive;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param PointPrimitive= obj
         * @returns PointPrimitive
         */
        static getSizePrefixedRootAsPointPrimitive(bb: flatbuffers.ByteBuffer, obj?: PointPrimitive): PointPrimitive;
        /**
         * @param number index
         * @param DPoint3d= obj
         * @returns DPoint3d
         */
        coords(index: number, obj?: DPoint3d): DPoint3d | null;
        /**
         * @returns number
         */
        coordsLength(): number;
        /**
         * @returns BoundaryType
         */
        boundary(): BoundaryType;
        /**
         * @param flatbuffers.Builder builder
         */
        static startPointPrimitive(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset coordsOffset
         */
        static addCoords(builder: flatbuffers.Builder, coordsOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startCoordsVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param BoundaryType boundary
         */
        static addBoundary(builder: flatbuffers.Builder, boundary: BoundaryType): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endPointPrimitive(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createPointPrimitive(builder: flatbuffers.Builder, coordsOffset: flatbuffers.Offset, boundary: BoundaryType): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class PointPrimitive2d {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns PointPrimitive2d
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): PointPrimitive2d;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param PointPrimitive2d= obj
         * @returns PointPrimitive2d
         */
        static getRootAsPointPrimitive2d(bb: flatbuffers.ByteBuffer, obj?: PointPrimitive2d): PointPrimitive2d;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param PointPrimitive2d= obj
         * @returns PointPrimitive2d
         */
        static getSizePrefixedRootAsPointPrimitive2d(bb: flatbuffers.ByteBuffer, obj?: PointPrimitive2d): PointPrimitive2d;
        /**
         * @param number index
         * @param DPoint2d= obj
         * @returns DPoint2d
         */
        coords(index: number, obj?: DPoint2d): DPoint2d | null;
        /**
         * @returns number
         */
        coordsLength(): number;
        /**
         * @returns BoundaryType
         */
        boundary(): BoundaryType;
        /**
         * @param flatbuffers.Builder builder
         */
        static startPointPrimitive2d(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset coordsOffset
         */
        static addCoords(builder: flatbuffers.Builder, coordsOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startCoordsVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param BoundaryType boundary
         */
        static addBoundary(builder: flatbuffers.Builder, boundary: BoundaryType): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endPointPrimitive2d(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createPointPrimitive2d(builder: flatbuffers.Builder, coordsOffset: flatbuffers.Offset, boundary: BoundaryType): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class ArcPrimitive {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns ArcPrimitive
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): ArcPrimitive;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param ArcPrimitive= obj
         * @returns ArcPrimitive
         */
        static getRootAsArcPrimitive(bb: flatbuffers.ByteBuffer, obj?: ArcPrimitive): ArcPrimitive;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param ArcPrimitive= obj
         * @returns ArcPrimitive
         */
        static getSizePrefixedRootAsArcPrimitive(bb: flatbuffers.ByteBuffer, obj?: ArcPrimitive): ArcPrimitive;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        center(obj?: DPoint3d): DPoint3d | null;
        /**
         * @param DVec3d= obj
         * @returns DVec3d|null
         */
        vector0(obj?: DVec3d): DVec3d | null;
        /**
         * @param DVec3d= obj
         * @returns DVec3d|null
         */
        vector90(obj?: DVec3d): DVec3d | null;
        /**
         * @returns number
         */
        start(): number;
        /**
         * @returns number
         */
        sweep(): number;
        /**
         * @returns BoundaryType
         */
        boundary(): BoundaryType;
        /**
         * @param flatbuffers.Builder builder
         */
        static startArcPrimitive(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset centerOffset
         */
        static addCenter(builder: flatbuffers.Builder, centerOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset vector0Offset
         */
        static addVector0(builder: flatbuffers.Builder, vector0Offset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset vector90Offset
         */
        static addVector90(builder: flatbuffers.Builder, vector90Offset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number start
         */
        static addStart(builder: flatbuffers.Builder, start: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number sweep
         */
        static addSweep(builder: flatbuffers.Builder, sweep: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param BoundaryType boundary
         */
        static addBoundary(builder: flatbuffers.Builder, boundary: BoundaryType): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endArcPrimitive(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createArcPrimitive(builder: flatbuffers.Builder, centerOffset: flatbuffers.Offset, vector0Offset: flatbuffers.Offset, vector90Offset: flatbuffers.Offset, start: number, sweep: number, boundary: BoundaryType): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class BRepData {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns BRepData
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): BRepData;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param BRepData= obj
         * @returns BRepData
         */
        static getRootAsBRepData(bb: flatbuffers.ByteBuffer, obj?: BRepData): BRepData;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param BRepData= obj
         * @returns BRepData
         */
        static getSizePrefixedRootAsBRepData(bb: flatbuffers.ByteBuffer, obj?: BRepData): BRepData;
        /**
         * @param Transform= obj
         * @returns Transform|null
         */
        entityTransform(obj?: Transform): Transform | null;
        /**
         * @returns BRepType
         */
        brepType(): BRepType;
        /**
         * @param number index
         * @returns number
         */
        entityData(index: number): number | null;
        /**
         * @returns number
         */
        entityDataLength(): number;
        /**
         * @returns Uint8Array
         */
        entityDataArray(): Uint8Array | null;
        /**
         * @param number index
         * @param FaceSymbology= obj
         * @returns FaceSymbology
         */
        symbology(index: number, obj?: FaceSymbology): FaceSymbology | null;
        /**
         * @returns number
         */
        symbologyLength(): number;
        /**
         * @param number index
         * @param FaceSymbologyIndex= obj
         * @returns FaceSymbologyIndex
         */
        symbologyIndex(index: number, obj?: FaceSymbologyIndex): FaceSymbologyIndex | null;
        /**
         * @returns number
         */
        symbologyIndexLength(): number;
        /**
         * @param flatbuffers.Builder builder
         */
        static startBRepData(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset entityTransformOffset
         */
        static addEntityTransform(builder: flatbuffers.Builder, entityTransformOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param BRepType brepType
         */
        static addBrepType(builder: flatbuffers.Builder, brepType: BRepType): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset entityDataOffset
         */
        static addEntityData(builder: flatbuffers.Builder, entityDataOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param Array.<number> data
         * @returns flatbuffers.Offset
         */
        static createEntityDataVector(builder: flatbuffers.Builder, data: number[] | Uint8Array): flatbuffers.Offset;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startEntityDataVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset symbologyOffset
         */
        static addSymbology(builder: flatbuffers.Builder, symbologyOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startSymbologyVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset symbologyIndexOffset
         */
        static addSymbologyIndex(builder: flatbuffers.Builder, symbologyIndexOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startSymbologyIndexVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endBRepData(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createBRepData(builder: flatbuffers.Builder, entityTransformOffset: flatbuffers.Offset, brepType: BRepType, entityDataOffset: flatbuffers.Offset, symbologyOffset: flatbuffers.Offset, symbologyIndexOffset: flatbuffers.Offset): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class Image {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns Image
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): Image;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param Image= obj
         * @returns Image
         */
        static getRootAsImage(bb: flatbuffers.ByteBuffer, obj?: Image): Image;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param Image= obj
         * @returns Image
         */
        static getSizePrefixedRootAsImage(bb: flatbuffers.ByteBuffer, obj?: Image): Image;
        /**
         * @returns number
         */
        drawBorder(): number;
        /**
         * @returns number
         */
        useFillTint(): number;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        tileCorner0(obj?: DPoint3d): DPoint3d | null;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        tileCorner1(obj?: DPoint3d): DPoint3d | null;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        tileCorner2(obj?: DPoint3d): DPoint3d | null;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        tileCorner3(obj?: DPoint3d): DPoint3d | null;
        /**
         * @returns number
         */
        width(): number;
        /**
         * @returns number
         */
        height(): number;
        /**
         * @returns number
         */
        format(): number;
        /**
         * @param number index
         * @returns number
         */
        byteData(index: number): number | null;
        /**
         * @returns number
         */
        byteDataLength(): number;
        /**
         * @returns Uint8Array
         */
        byteDataArray(): Uint8Array | null;
        /**
         * @returns flatbuffers.Long
         */
        textureId(): flatbuffers.Long;
        /**
         * @param flatbuffers.Builder builder
         */
        static startImage(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number drawBorder
         */
        static addDrawBorder(builder: flatbuffers.Builder, drawBorder: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number useFillTint
         */
        static addUseFillTint(builder: flatbuffers.Builder, useFillTint: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset tileCorner0Offset
         */
        static addTileCorner0(builder: flatbuffers.Builder, tileCorner0Offset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset tileCorner1Offset
         */
        static addTileCorner1(builder: flatbuffers.Builder, tileCorner1Offset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset tileCorner2Offset
         */
        static addTileCorner2(builder: flatbuffers.Builder, tileCorner2Offset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset tileCorner3Offset
         */
        static addTileCorner3(builder: flatbuffers.Builder, tileCorner3Offset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number width
         */
        static addWidth(builder: flatbuffers.Builder, width: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number height
         */
        static addHeight(builder: flatbuffers.Builder, height: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number format
         */
        static addFormat(builder: flatbuffers.Builder, format: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset byteDataOffset
         */
        static addByteData(builder: flatbuffers.Builder, byteDataOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param Array.<number> data
         * @returns flatbuffers.Offset
         */
        static createByteDataVector(builder: flatbuffers.Builder, data: number[] | Uint8Array): flatbuffers.Offset;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startByteDataVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Long textureId
         */
        static addTextureId(builder: flatbuffers.Builder, textureId: flatbuffers.Long): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endImage(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createImage(builder: flatbuffers.Builder, drawBorder: number, useFillTint: number, tileCorner0Offset: flatbuffers.Offset, tileCorner1Offset: flatbuffers.Offset, tileCorner2Offset: flatbuffers.Offset, tileCorner3Offset: flatbuffers.Offset, width: number, height: number, format: number, byteDataOffset: flatbuffers.Offset, textureId: flatbuffers.Long): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class GeometryPart {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns GeometryPart
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): GeometryPart;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param GeometryPart= obj
         * @returns GeometryPart
         */
        static getRootAsGeometryPart(bb: flatbuffers.ByteBuffer, obj?: GeometryPart): GeometryPart;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param GeometryPart= obj
         * @returns GeometryPart
         */
        static getSizePrefixedRootAsGeometryPart(bb: flatbuffers.ByteBuffer, obj?: GeometryPart): GeometryPart;
        /**
         * @returns flatbuffers.Long
         */
        geomPartId(): flatbuffers.Long;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        origin(obj?: DPoint3d): DPoint3d | null;
        /**
         * @returns number
         */
        yaw(): number;
        /**
         * @returns number
         */
        pitch(): number;
        /**
         * @returns number
         */
        roll(): number;
        /**
         * @returns number
         */
        scale(): number;
        /**
         * @param flatbuffers.Builder builder
         */
        static startGeometryPart(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Long geomPartId
         */
        static addGeomPartId(builder: flatbuffers.Builder, geomPartId: flatbuffers.Long): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset originOffset
         */
        static addOrigin(builder: flatbuffers.Builder, originOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number yaw
         */
        static addYaw(builder: flatbuffers.Builder, yaw: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number pitch
         */
        static addPitch(builder: flatbuffers.Builder, pitch: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number roll
         */
        static addRoll(builder: flatbuffers.Builder, roll: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number scale
         */
        static addScale(builder: flatbuffers.Builder, scale: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endGeometryPart(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createGeometryPart(builder: flatbuffers.Builder, geomPartId: flatbuffers.Long, originOffset: flatbuffers.Offset, yaw: number, pitch: number, roll: number, scale: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class BasicSymbology {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns BasicSymbology
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): BasicSymbology;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param BasicSymbology= obj
         * @returns BasicSymbology
         */
        static getRootAsBasicSymbology(bb: flatbuffers.ByteBuffer, obj?: BasicSymbology): BasicSymbology;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param BasicSymbology= obj
         * @returns BasicSymbology
         */
        static getSizePrefixedRootAsBasicSymbology(bb: flatbuffers.ByteBuffer, obj?: BasicSymbology): BasicSymbology;
        /**
         * @returns flatbuffers.Long
         */
        subCategoryId(): flatbuffers.Long;
        /**
         * @returns number
         */
        color(): number;
        /**
         * @returns number
         */
        weight(): number;
        /**
         * @returns flatbuffers.Long
         */
        lineStyleId(): flatbuffers.Long;
        /**
         * @returns number
         */
        transparency(): number;
        /**
         * @returns number
         */
        displayPriority(): number;
        /**
         * @returns GeometryClass
         */
        geomClass(): GeometryClass;
        /**
         * @returns number
         */
        useColor(): number;
        /**
         * @returns number
         */
        useWeight(): number;
        /**
         * @returns number
         */
        useStyle(): number;
        /**
         * @param flatbuffers.Builder builder
         */
        static startBasicSymbology(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Long subCategoryId
         */
        static addSubCategoryId(builder: flatbuffers.Builder, subCategoryId: flatbuffers.Long): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number color
         */
        static addColor(builder: flatbuffers.Builder, color: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number weight
         */
        static addWeight(builder: flatbuffers.Builder, weight: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Long lineStyleId
         */
        static addLineStyleId(builder: flatbuffers.Builder, lineStyleId: flatbuffers.Long): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number transparency
         */
        static addTransparency(builder: flatbuffers.Builder, transparency: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number displayPriority
         */
        static addDisplayPriority(builder: flatbuffers.Builder, displayPriority: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param GeometryClass geomClass
         */
        static addGeomClass(builder: flatbuffers.Builder, geomClass: GeometryClass): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number useColor
         */
        static addUseColor(builder: flatbuffers.Builder, useColor: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number useWeight
         */
        static addUseWeight(builder: flatbuffers.Builder, useWeight: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number useStyle
         */
        static addUseStyle(builder: flatbuffers.Builder, useStyle: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endBasicSymbology(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createBasicSymbology(builder: flatbuffers.Builder, subCategoryId: flatbuffers.Long, color: number, weight: number, lineStyleId: flatbuffers.Long, transparency: number, displayPriority: number, geomClass: GeometryClass, useColor: number, useWeight: number, useStyle: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class LineStyleModifiers {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns LineStyleModifiers
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): LineStyleModifiers;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param LineStyleModifiers= obj
         * @returns LineStyleModifiers
         */
        static getRootAsLineStyleModifiers(bb: flatbuffers.ByteBuffer, obj?: LineStyleModifiers): LineStyleModifiers;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param LineStyleModifiers= obj
         * @returns LineStyleModifiers
         */
        static getSizePrefixedRootAsLineStyleModifiers(bb: flatbuffers.ByteBuffer, obj?: LineStyleModifiers): LineStyleModifiers;
        /**
         * @returns number
         */
        modifiers(): number;
        /**
         * @returns number
         */
        scale(): number;
        /**
         * @returns number
         */
        dashScale(): number;
        /**
         * @returns number
         */
        gapScale(): number;
        /**
         * @returns number
         */
        startWidth(): number;
        /**
         * @returns number
         */
        endWidth(): number;
        /**
         * @returns number
         */
        distPhase(): number;
        /**
         * @returns number
         */
        fractPhase(): number;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        normal(obj?: DPoint3d): DPoint3d | null;
        /**
         * @returns number
         */
        yaw(): number;
        /**
         * @returns number
         */
        pitch(): number;
        /**
         * @returns number
         */
        roll(): number;
        /**
         * @param flatbuffers.Builder builder
         */
        static startLineStyleModifiers(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number modifiers
         */
        static addModifiers(builder: flatbuffers.Builder, modifiers: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number scale
         */
        static addScale(builder: flatbuffers.Builder, scale: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number dashScale
         */
        static addDashScale(builder: flatbuffers.Builder, dashScale: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number gapScale
         */
        static addGapScale(builder: flatbuffers.Builder, gapScale: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number startWidth
         */
        static addStartWidth(builder: flatbuffers.Builder, startWidth: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number endWidth
         */
        static addEndWidth(builder: flatbuffers.Builder, endWidth: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number distPhase
         */
        static addDistPhase(builder: flatbuffers.Builder, distPhase: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number fractPhase
         */
        static addFractPhase(builder: flatbuffers.Builder, fractPhase: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset normalOffset
         */
        static addNormal(builder: flatbuffers.Builder, normalOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number yaw
         */
        static addYaw(builder: flatbuffers.Builder, yaw: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number pitch
         */
        static addPitch(builder: flatbuffers.Builder, pitch: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number roll
         */
        static addRoll(builder: flatbuffers.Builder, roll: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endLineStyleModifiers(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createLineStyleModifiers(builder: flatbuffers.Builder, modifiers: number, scale: number, dashScale: number, gapScale: number, startWidth: number, endWidth: number, distPhase: number, fractPhase: number, normalOffset: flatbuffers.Offset, yaw: number, pitch: number, roll: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class Material {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns Material
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): Material;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param Material= obj
         * @returns Material
         */
        static getRootAsMaterial(bb: flatbuffers.ByteBuffer, obj?: Material): Material;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param Material= obj
         * @returns Material
         */
        static getSizePrefixedRootAsMaterial(bb: flatbuffers.ByteBuffer, obj?: Material): Material;
        /**
         * @returns number
         */
        useMaterial(): number;
        /**
         * @returns flatbuffers.Long
         */
        materialId(): flatbuffers.Long;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        origin(obj?: DPoint3d): DPoint3d | null;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        size(obj?: DPoint3d): DPoint3d | null;
        /**
         * @returns number
         */
        yaw(): number;
        /**
         * @returns number
         */
        pitch(): number;
        /**
         * @returns number
         */
        roll(): number;
        /**
         * @param Trans2x3= obj
         * @returns Trans2x3|null
         */
        trans2x3(obj?: Trans2x3): Trans2x3 | null;
        /**
         * @param flatbuffers.Builder builder
         */
        static startMaterial(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number useMaterial
         */
        static addUseMaterial(builder: flatbuffers.Builder, useMaterial: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Long materialId
         */
        static addMaterialId(builder: flatbuffers.Builder, materialId: flatbuffers.Long): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset originOffset
         */
        static addOrigin(builder: flatbuffers.Builder, originOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset sizeOffset
         */
        static addSize(builder: flatbuffers.Builder, sizeOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number yaw
         */
        static addYaw(builder: flatbuffers.Builder, yaw: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number pitch
         */
        static addPitch(builder: flatbuffers.Builder, pitch: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number roll
         */
        static addRoll(builder: flatbuffers.Builder, roll: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset trans2x3Offset
         */
        static addTrans2x3(builder: flatbuffers.Builder, trans2x3Offset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endMaterial(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createMaterial(builder: flatbuffers.Builder, useMaterial: number, materialId: flatbuffers.Long, originOffset: flatbuffers.Offset, sizeOffset: flatbuffers.Offset, yaw: number, pitch: number, roll: number, trans2x3Offset: flatbuffers.Offset): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class ThematicSettings {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns ThematicSettings
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): ThematicSettings;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param ThematicSettings= obj
         * @returns ThematicSettings
         */
        static getRootAsThematicSettings(bb: flatbuffers.ByteBuffer, obj?: ThematicSettings): ThematicSettings;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param ThematicSettings= obj
         * @returns ThematicSettings
         */
        static getSizePrefixedRootAsThematicSettings(bb: flatbuffers.ByteBuffer, obj?: ThematicSettings): ThematicSettings;
        /**
         * @returns number
         */
        stepCount(): number;
        /**
         * @returns number
         */
        margin(): number;
        /**
         * @returns number
         */
        marginColor(): number;
        /**
         * @returns number
         */
        mode(): number;
        /**
         * @returns number
         */
        colorScheme(): number;
        /**
         * @param DRange1d= obj
         * @returns DRange1d|null
         */
        range(obj?: DRange1d): DRange1d | null;
        /**
         * @param flatbuffers.Builder builder
         */
        static startThematicSettings(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number stepCount
         */
        static addStepCount(builder: flatbuffers.Builder, stepCount: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number margin
         */
        static addMargin(builder: flatbuffers.Builder, margin: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number marginColor
         */
        static addMarginColor(builder: flatbuffers.Builder, marginColor: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number mode
         */
        static addMode(builder: flatbuffers.Builder, mode: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number colorScheme
         */
        static addColorScheme(builder: flatbuffers.Builder, colorScheme: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset rangeOffset
         */
        static addRange(builder: flatbuffers.Builder, rangeOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endThematicSettings(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createThematicSettings(builder: flatbuffers.Builder, stepCount: number, margin: number, marginColor: number, mode: number, colorScheme: number, rangeOffset: flatbuffers.Offset): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class AreaFill {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns AreaFill
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): AreaFill;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param AreaFill= obj
         * @returns AreaFill
         */
        static getRootAsAreaFill(bb: flatbuffers.ByteBuffer, obj?: AreaFill): AreaFill;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param AreaFill= obj
         * @returns AreaFill
         */
        static getSizePrefixedRootAsAreaFill(bb: flatbuffers.ByteBuffer, obj?: AreaFill): AreaFill;
        /**
         * @returns FillDisplay
         */
        fill(): FillDisplay;
        /**
         * @returns number
         */
        color(): number;
        /**
         * @returns number
         */
        useColor(): number;
        /**
         * @returns number
         */
        backgroundFill(): number;
        /**
         * @returns number
         */
        transparency(): number;
        /**
         * @returns GradientMode
         */
        mode(): GradientMode;
        /**
         * @returns number
         */
        flags(): number;
        /**
         * @returns number
         */
        angle(): number;
        /**
         * @returns number
         */
        tint(): number;
        /**
         * @returns number
         */
        shift(): number;
        /**
         * @param number index
         * @returns number
         */
        colors(index: number): number | null;
        /**
         * @returns number
         */
        colorsLength(): number;
        /**
         * @returns Uint32Array
         */
        colorsArray(): Uint32Array | null;
        /**
         * @param number index
         * @returns number
         */
        values(index: number): number | null;
        /**
         * @returns number
         */
        valuesLength(): number;
        /**
         * @returns Float64Array
         */
        valuesArray(): Float64Array | null;
        /**
         * @param ThematicSettings= obj
         * @returns ThematicSettings|null
         */
        thematicSettings(obj?: ThematicSettings): ThematicSettings | null;
        /**
         * @param flatbuffers.Builder builder
         */
        static startAreaFill(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param FillDisplay fill
         */
        static addFill(builder: flatbuffers.Builder, fill: FillDisplay): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number color
         */
        static addColor(builder: flatbuffers.Builder, color: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number useColor
         */
        static addUseColor(builder: flatbuffers.Builder, useColor: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number backgroundFill
         */
        static addBackgroundFill(builder: flatbuffers.Builder, backgroundFill: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number transparency
         */
        static addTransparency(builder: flatbuffers.Builder, transparency: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param GradientMode mode
         */
        static addMode(builder: flatbuffers.Builder, mode: GradientMode): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number flags
         */
        static addFlags(builder: flatbuffers.Builder, flags: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number angle
         */
        static addAngle(builder: flatbuffers.Builder, angle: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number tint
         */
        static addTint(builder: flatbuffers.Builder, tint: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number shift
         */
        static addShift(builder: flatbuffers.Builder, shift: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset colorsOffset
         */
        static addColors(builder: flatbuffers.Builder, colorsOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param Array.<number> data
         * @returns flatbuffers.Offset
         */
        static createColorsVector(builder: flatbuffers.Builder, data: number[] | Uint8Array): flatbuffers.Offset;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startColorsVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset valuesOffset
         */
        static addValues(builder: flatbuffers.Builder, valuesOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param Array.<number> data
         * @returns flatbuffers.Offset
         */
        static createValuesVector(builder: flatbuffers.Builder, data: number[] | Uint8Array): flatbuffers.Offset;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startValuesVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset thematicSettingsOffset
         */
        static addThematicSettings(builder: flatbuffers.Builder, thematicSettingsOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endAreaFill(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createAreaFill(builder: flatbuffers.Builder, fill: FillDisplay, color: number, useColor: number, backgroundFill: number, transparency: number, mode: GradientMode, flags: number, angle: number, tint: number, shift: number, colorsOffset: flatbuffers.Offset, valuesOffset: flatbuffers.Offset, thematicSettingsOffset: flatbuffers.Offset): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class DwgHatchDefLine {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns DwgHatchDefLine
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): DwgHatchDefLine;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param DwgHatchDefLine= obj
         * @returns DwgHatchDefLine
         */
        static getRootAsDwgHatchDefLine(bb: flatbuffers.ByteBuffer, obj?: DwgHatchDefLine): DwgHatchDefLine;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param DwgHatchDefLine= obj
         * @returns DwgHatchDefLine
         */
        static getSizePrefixedRootAsDwgHatchDefLine(bb: flatbuffers.ByteBuffer, obj?: DwgHatchDefLine): DwgHatchDefLine;
        /**
         * @returns number
         */
        angle(): number;
        /**
         * @param DPoint2d= obj
         * @returns DPoint2d|null
         */
        through(obj?: DPoint2d): DPoint2d | null;
        /**
         * @param DPoint2d= obj
         * @returns DPoint2d|null
         */
        offset(obj?: DPoint2d): DPoint2d | null;
        /**
         * @param number index
         * @returns number
         */
        dashes(index: number): number | null;
        /**
         * @returns number
         */
        dashesLength(): number;
        /**
         * @returns Float64Array
         */
        dashesArray(): Float64Array | null;
        /**
         * @param flatbuffers.Builder builder
         */
        static startDwgHatchDefLine(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number angle
         */
        static addAngle(builder: flatbuffers.Builder, angle: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset throughOffset
         */
        static addThrough(builder: flatbuffers.Builder, throughOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset offsetOffset
         */
        static addOffset(builder: flatbuffers.Builder, offsetOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset dashesOffset
         */
        static addDashes(builder: flatbuffers.Builder, dashesOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param Array.<number> data
         * @returns flatbuffers.Offset
         */
        static createDashesVector(builder: flatbuffers.Builder, data: number[] | Uint8Array): flatbuffers.Offset;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startDashesVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endDwgHatchDefLine(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createDwgHatchDefLine(builder: flatbuffers.Builder, angle: number, throughOffset: flatbuffers.Offset, offsetOffset: flatbuffers.Offset, dashesOffset: flatbuffers.Offset): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class AreaPattern {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns AreaPattern
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): AreaPattern;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param AreaPattern= obj
         * @returns AreaPattern
         */
        static getRootAsAreaPattern(bb: flatbuffers.ByteBuffer, obj?: AreaPattern): AreaPattern;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param AreaPattern= obj
         * @returns AreaPattern
         */
        static getSizePrefixedRootAsAreaPattern(bb: flatbuffers.ByteBuffer, obj?: AreaPattern): AreaPattern;
        /**
         * @param DPoint3d= obj
         * @returns DPoint3d|null
         */
        origin(obj?: DPoint3d): DPoint3d | null;
        /**
         * @param RotMatrix= obj
         * @returns RotMatrix|null
         */
        rotation(obj?: RotMatrix): RotMatrix | null;
        /**
         * @returns number
         */
        space1(): number;
        /**
         * @returns number
         */
        space2(): number;
        /**
         * @returns number
         */
        angle1(): number;
        /**
         * @returns number
         */
        angle2(): number;
        /**
         * @returns number
         */
        scale(): number;
        /**
         * @returns number
         */
        color(): number;
        /**
         * @returns number
         */
        weight(): number;
        /**
         * @returns number
         */
        useColor(): number;
        /**
         * @returns number
         */
        useWeight(): number;
        /**
         * @returns number
         */
        invisibleBoundary(): number;
        /**
         * @returns number
         */
        snappable(): number;
        /**
         * @returns flatbuffers.Long
         */
        symbolId(): flatbuffers.Long;
        /**
         * @param number index
         * @param DwgHatchDefLine= obj
         * @returns DwgHatchDefLine
         */
        defLine(index: number, obj?: DwgHatchDefLine): DwgHatchDefLine | null;
        /**
         * @returns number
         */
        defLineLength(): number;
        /**
         * @param flatbuffers.Builder builder
         */
        static startAreaPattern(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset originOffset
         */
        static addOrigin(builder: flatbuffers.Builder, originOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset rotationOffset
         */
        static addRotation(builder: flatbuffers.Builder, rotationOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number space1
         */
        static addSpace1(builder: flatbuffers.Builder, space1: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number space2
         */
        static addSpace2(builder: flatbuffers.Builder, space2: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number angle1
         */
        static addAngle1(builder: flatbuffers.Builder, angle1: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number angle2
         */
        static addAngle2(builder: flatbuffers.Builder, angle2: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number scale
         */
        static addScale(builder: flatbuffers.Builder, scale: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number color
         */
        static addColor(builder: flatbuffers.Builder, color: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number weight
         */
        static addWeight(builder: flatbuffers.Builder, weight: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number useColor
         */
        static addUseColor(builder: flatbuffers.Builder, useColor: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number useWeight
         */
        static addUseWeight(builder: flatbuffers.Builder, useWeight: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number invisibleBoundary
         */
        static addInvisibleBoundary(builder: flatbuffers.Builder, invisibleBoundary: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number snappable
         */
        static addSnappable(builder: flatbuffers.Builder, snappable: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Long symbolId
         */
        static addSymbolId(builder: flatbuffers.Builder, symbolId: flatbuffers.Long): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset defLineOffset
         */
        static addDefLine(builder: flatbuffers.Builder, defLineOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param Array.<flatbuffers.Offset> data
         * @returns flatbuffers.Offset
         */
        static createDefLineVector(builder: flatbuffers.Builder, data: flatbuffers.Offset[]): flatbuffers.Offset;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startDefLineVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endAreaPattern(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createAreaPattern(builder: flatbuffers.Builder, originOffset: flatbuffers.Offset, rotationOffset: flatbuffers.Offset, space1: number, space2: number, angle1: number, angle2: number, scale: number, color: number, weight: number, useColor: number, useWeight: number, invisibleBoundary: number, snappable: number, symbolId: flatbuffers.Long, defLineOffset: flatbuffers.Offset): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class TextStringTransform {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns TextStringTransform
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): TextStringTransform;
        /**
         * @returns number
         */
        form3d00(): number;
        /**
         * @returns number
         */
        form3d01(): number;
        /**
         * @returns number
         */
        form3d02(): number;
        /**
         * @returns number
         */
        form3d03(): number;
        /**
         * @returns number
         */
        form3d10(): number;
        /**
         * @returns number
         */
        form3d11(): number;
        /**
         * @returns number
         */
        form3d12(): number;
        /**
         * @returns number
         */
        form3d13(): number;
        /**
         * @returns number
         */
        form3d20(): number;
        /**
         * @returns number
         */
        form3d21(): number;
        /**
         * @returns number
         */
        form3d22(): number;
        /**
         * @returns number
         */
        form3d23(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number form3d00
         * @param number form3d01
         * @param number form3d02
         * @param number form3d03
         * @param number form3d10
         * @param number form3d11
         * @param number form3d12
         * @param number form3d13
         * @param number form3d20
         * @param number form3d21
         * @param number form3d22
         * @param number form3d23
         * @returns flatbuffers.Offset
         */
        static createTextStringTransform(builder: flatbuffers.Builder, form3d00: number, form3d01: number, form3d02: number, form3d03: number, form3d10: number, form3d11: number, form3d12: number, form3d13: number, form3d20: number, form3d21: number, form3d22: number, form3d23: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class TextStringRange {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns TextStringRange
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): TextStringRange;
        /**
         * @returns number
         */
        lowx(): number;
        /**
         * @returns number
         */
        lowy(): number;
        /**
         * @returns number
         */
        highx(): number;
        /**
         * @returns number
         */
        highy(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number lowx
         * @param number lowy
         * @param number highx
         * @param number highy
         * @returns flatbuffers.Offset
         */
        static createTextStringRange(builder: flatbuffers.Builder, lowx: number, lowy: number, highx: number, highy: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class TextStringGlyphOrigin {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns TextStringGlyphOrigin
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): TextStringGlyphOrigin;
        /**
         * @returns number
         */
        x(): number;
        /**
         * @returns number
         */
        y(): number;
        /**
         * @param flatbuffers.Builder builder
         * @param number x
         * @param number y
         * @returns flatbuffers.Offset
         */
        static createTextStringGlyphOrigin(builder: flatbuffers.Builder, x: number, y: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class TextStringStyle {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns TextStringStyle
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): TextStringStyle;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param TextStringStyle= obj
         * @returns TextStringStyle
         */
        static getRootAsTextStringStyle(bb: flatbuffers.ByteBuffer, obj?: TextStringStyle): TextStringStyle;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param TextStringStyle= obj
         * @returns TextStringStyle
         */
        static getSizePrefixedRootAsTextStringStyle(bb: flatbuffers.ByteBuffer, obj?: TextStringStyle): TextStringStyle;
        /**
         * @returns number
         */
        majorVersion(): number;
        /**
         * @returns number
         */
        minorVersion(): number;
        /**
         * @returns number
         */
        fontId(): number;
        /**
         * @returns boolean
         */
        isBold(): boolean;
        /**
         * @returns boolean
         */
        isItalic(): boolean;
        /**
         * @returns boolean
         */
        isUnderlined(): boolean;
        /**
         * @returns number
         */
        height(): number;
        /**
         * @returns number
         */
        widthFactor(): number;
        /**
         * @param flatbuffers.Builder builder
         */
        static startTextStringStyle(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number majorVersion
         */
        static addMajorVersion(builder: flatbuffers.Builder, majorVersion: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number minorVersion
         */
        static addMinorVersion(builder: flatbuffers.Builder, minorVersion: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number fontId
         */
        static addFontId(builder: flatbuffers.Builder, fontId: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param boolean isBold
         */
        static addIsBold(builder: flatbuffers.Builder, isBold: boolean): void;
        /**
         * @param flatbuffers.Builder builder
         * @param boolean isItalic
         */
        static addIsItalic(builder: flatbuffers.Builder, isItalic: boolean): void;
        /**
         * @param flatbuffers.Builder builder
         * @param boolean isUnderlined
         */
        static addIsUnderlined(builder: flatbuffers.Builder, isUnderlined: boolean): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number height
         */
        static addHeight(builder: flatbuffers.Builder, height: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number widthFactor
         */
        static addWidthFactor(builder: flatbuffers.Builder, widthFactor: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endTextStringStyle(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createTextStringStyle(builder: flatbuffers.Builder, majorVersion: number, minorVersion: number, fontId: number, isBold: boolean, isItalic: boolean, isUnderlined: boolean, height: number, widthFactor: number): flatbuffers.Offset;
    }
    /**
     * @constructor
     */
    class TextString {
        bb: flatbuffers.ByteBuffer | null;
        bb_pos: number;
        /**
         * @param number i
         * @param flatbuffers.ByteBuffer bb
         * @returns TextString
         */
        __init(i: number, bb: flatbuffers.ByteBuffer): TextString;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param TextString= obj
         * @returns TextString
         */
        static getRootAsTextString(bb: flatbuffers.ByteBuffer, obj?: TextString): TextString;
        /**
         * @param flatbuffers.ByteBuffer bb
         * @param TextString= obj
         * @returns TextString
         */
        static getSizePrefixedRootAsTextString(bb: flatbuffers.ByteBuffer, obj?: TextString): TextString;
        /**
         * @returns number
         */
        majorVersion(): number;
        /**
         * @returns number
         */
        minorVersion(): number;
        /**
         * @param flatbuffers.Encoding= optionalEncoding
         * @returns string|Uint8Array|null
         */
        text(): string | null;
        text(optionalEncoding: flatbuffers.Encoding): string | Uint8Array | null;
        /**
         * @param TextStringStyle= obj
         * @returns TextStringStyle|null
         */
        style(obj?: TextStringStyle): TextStringStyle | null;
        /**
         * @param TextStringTransform= obj
         * @returns TextStringTransform|null
         */
        transform(obj?: TextStringTransform): TextStringTransform | null;
        /**
         * @param TextStringRange= obj
         * @returns TextStringRange|null
         */
        range(obj?: TextStringRange): TextStringRange | null;
        /**
         * @param number index
         * @returns number
         */
        glyphIds(index: number): number | null;
        /**
         * @returns number
         */
        glyphIdsLength(): number;
        /**
         * @returns Uint32Array
         */
        glyphIdsArray(): Uint32Array | null;
        /**
         * @param number index
         * @param TextStringGlyphOrigin= obj
         * @returns TextStringGlyphOrigin
         */
        glyphOrigins(index: number, obj?: TextStringGlyphOrigin): TextStringGlyphOrigin | null;
        /**
         * @returns number
         */
        glyphOriginsLength(): number;
        /**
         * @param flatbuffers.Builder builder
         */
        static startTextString(builder: flatbuffers.Builder): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number majorVersion
         */
        static addMajorVersion(builder: flatbuffers.Builder, majorVersion: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number minorVersion
         */
        static addMinorVersion(builder: flatbuffers.Builder, minorVersion: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset textOffset
         */
        static addText(builder: flatbuffers.Builder, textOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset styleOffset
         */
        static addStyle(builder: flatbuffers.Builder, styleOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset transformOffset
         */
        static addTransform(builder: flatbuffers.Builder, transformOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset rangeOffset
         */
        static addRange(builder: flatbuffers.Builder, rangeOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset glyphIdsOffset
         */
        static addGlyphIds(builder: flatbuffers.Builder, glyphIdsOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param Array.<number> data
         * @returns flatbuffers.Offset
         */
        static createGlyphIdsVector(builder: flatbuffers.Builder, data: number[] | Uint8Array): flatbuffers.Offset;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startGlyphIdsVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @param flatbuffers.Offset glyphOriginsOffset
         */
        static addGlyphOrigins(builder: flatbuffers.Builder, glyphOriginsOffset: flatbuffers.Offset): void;
        /**
         * @param flatbuffers.Builder builder
         * @param number numElems
         */
        static startGlyphOriginsVector(builder: flatbuffers.Builder, numElems: number): void;
        /**
         * @param flatbuffers.Builder builder
         * @returns flatbuffers.Offset
         */
        static endTextString(builder: flatbuffers.Builder): flatbuffers.Offset;
        static createTextString(builder: flatbuffers.Builder, majorVersion: number, minorVersion: number, textOffset: flatbuffers.Offset, styleOffset: flatbuffers.Offset, transformOffset: flatbuffers.Offset, rangeOffset: flatbuffers.Offset, glyphIdsOffset: flatbuffers.Offset, glyphOriginsOffset: flatbuffers.Offset): flatbuffers.Offset;
    }
}
//# sourceMappingURL=ElementGeometryFB.d.ts.map