/** @packageDocumentation
 * @module Geometry
 */
import { ClipPlane, Point3d, Vector3d } from "@bentley/geometry-core";
import { Frustum } from "../Frustum";
import { BoundingSphere } from "./BoundingSphere";
/** Represents a frustum as 6 planes and provides containment and intersection testing
 * @internal
 */
export declare class FrustumPlanes {
    private _planes?;
    constructor(frustum?: Frustum);
    get isValid(): boolean;
    get planes(): ClipPlane[] | undefined;
    init(frustum: Frustum): void;
    computeFrustumContainment(box: Frustum, sphere?: BoundingSphere): FrustumPlanes.Containment;
    intersectsFrustum(box: Frustum): boolean;
    containsPoint(point: Point3d, tolerance?: number): boolean;
    computeContainment(points: Point3d[], sphere?: BoundingSphere, tolerance?: number): FrustumPlanes.Containment;
    intersectsRay(origin: Point3d, direction: Vector3d): boolean;
}
/** @internal */
export declare namespace FrustumPlanes {
    /** @internal */
    enum Containment {
        Outside = 0,
        Partial = 1,
        Inside = 2
    }
    /** @internal */
    function addPlaneFromPoints(planes: ClipPlane[], points: Point3d[], i0: number, i1: number, i2: number, expandPlaneDistance?: number): void;
}
//# sourceMappingURL=FrustumPlanes.d.ts.map