/** @packageDocumentation
 * @module Geometry
 */
import { Point3d, Transform, XYZProps, YawPitchRollAngles, YawPitchRollProps } from "@bentley/geometry-core";
/** Properties for a TextString class.
 * @see [[GeometryStreamEntryProps]]
 * @public
 */
export interface TextStringProps {
    /** text string */
    text: string;
    /** font number. Font numbers are mapped to font names and types via the FontMap */
    font: number;
    height: number;
    widthFactor?: number;
    /** bold text. Default is false */
    bold?: boolean;
    /** italic text. Default is false */
    italic?: boolean;
    /** underline text. Default is false */
    underline?: boolean;
    /** Optional position relative to element's placement. Default is 0,0,0 */
    origin?: XYZProps;
    /** Optional rotation relative to element's placement. Default is identity matrix */
    rotation?: YawPitchRollProps;
}
/** A single line of text, all with the same font, styles (underline, bold, italic), and size.
 * This class also holds the origin and direction for the text.
 * A paragraph is composed of one or more instances of TextStrings.
 * @public
 */
export declare class TextString {
    /** Text string */
    text: string;
    /** font number. Font numbers are mapped to font names and types via the FontMap */
    font: number;
    height: number;
    widthFactor?: number;
    /** bold text. Default is false */
    bold?: boolean;
    /** italic text. Default is false */
    italic?: boolean;
    /** underline text. Default is false */
    underline?: boolean;
    /** position relative to element's placement */
    readonly origin: Point3d;
    /** Rotation relative to element's placement */
    readonly rotation: YawPitchRollAngles;
    get width(): number;
    constructor(props: TextStringProps);
    toJSON(): TextStringProps;
    transformInPlace(transform: Transform): boolean;
}
//# sourceMappingURL=TextString.d.ts.map