/** @packageDocumentation
 * @module RpcInterface
 */
import { LogLevel } from "@bentley/bentleyjs-core";
import { IModelRpcProps } from "../IModel";
import { RpcInterface } from "../RpcInterface";
/** Options to get the backend statistics
 * @internal
 */
export declare enum DevToolsStatsOptions {
    None = 0,
    /** All unitized values are setup as formatted strings with the appropriate units */
    FormatUnits = 1
}
/** The purpose of this class is to house RPC methods for developer tools.
 * Note that this should NOT be used in production environments.
 * @internal
 */
export declare abstract class DevToolsRpcInterface extends RpcInterface {
    /** Returns the IModelReadRpcInterface instance for the frontend. */
    static getClient(): DevToolsRpcInterface;
    /** The immutable name of the interface. */
    static readonly interfaceName = "DevToolsRpcInterface";
    /** The semantic version of the interface.
     * @note The DevToolsRpcInterface will remain at 0.x since it is for testing only and not intended for production.
     */
    static interfaceVersion: string;
    ping(_iModelToken: IModelRpcProps): Promise<boolean>;
    stats(_iModelToken: IModelRpcProps, _options: DevToolsStatsOptions): Promise<any>;
    versions(_iModelToken: IModelRpcProps): Promise<any>;
    setLogLevel(_iModelToken: IModelRpcProps, _loggerCategory: string, _logLevel: LogLevel): Promise<LogLevel | undefined>;
}
//# sourceMappingURL=DevToolsRpcInterface.d.ts.map