"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module RpcInterface
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IModelReadRpcInterface = exports.IModelNotFoundResponse = void 0;
const RpcInterface_1 = require("../RpcInterface");
const RpcManager_1 = require("../RpcManager");
const RpcControl_1 = require("./core/RpcControl");
/** Response if the IModelDb was not found at the backend
 * (if the service has moved)
 * @public
 */
class IModelNotFoundResponse extends RpcControl_1.RpcNotFoundResponse {
    constructor() {
        super(...arguments);
        this.isIModelNotFoundResponse = true;
    }
}
exports.IModelNotFoundResponse = IModelNotFoundResponse;
/** The RPC interface for reading from an iModel.
 * All operations only require read-only access.
 * This interface is not normally used directly. See IModelConnection for higher-level and more convenient API for accessing iModels from a frontend.
 * @internal
 */
class IModelReadRpcInterface extends RpcInterface_1.RpcInterface {
    /** Returns the IModelReadRpcInterface instance for the frontend. */
    static getClient() { return RpcManager_1.RpcManager.getClientForInterface(IModelReadRpcInterface); }
    /** Returns the IModelReadRpcInterface instance for a custom RPC routing configuration. */
    static getClientForRouting(token) { return RpcManager_1.RpcManager.getClientForInterface(IModelReadRpcInterface, token); }
    /*===========================================================================================
      NOTE: Any add/remove/change to the methods below requires an update of the interface version.
      NOTE: Please consult the README in this folder for the semantic versioning rules.
    ===========================================================================================*/
    async openForRead(_iModelToken) { return this.forward(arguments); }
    async close(_iModelToken) { return this.forward(arguments); }
    async queryRows(_iModelToken, _ecsql, _bindings, _limit, _quota, _priority, _restartToken, _abbreviateBlobs) { return this.forward(arguments); }
    async getModelProps(_iModelToken, _modelIds) { return this.forward(arguments); }
    async queryModelRanges(_iModelToken, _modelIds) { return this.forward(arguments); }
    async queryModelProps(_iModelToken, _params) { return this.forward(arguments); }
    async getElementProps(_iModelToken, _elementIds) { return this.forward(arguments); }
    async queryElementProps(_iModelToken, _params) { return this.forward(arguments); }
    async queryEntityIds(_iModelToken, _params) { return this.forward(arguments); }
    async getClassHierarchy(_iModelToken, _startClassName) { return this.forward(arguments); }
    async getAllCodeSpecs(_iModelToken) { return this.forward(arguments); }
    async getViewStateData(_iModelToken, _viewDefinitionId, _options) { return this.forward(arguments); }
    async readFontJson(_iModelToken) { return this.forward(arguments); }
    async getToolTipMessage(_iModelToken, _elementId) { return this.forward(arguments); }
    async getViewThumbnail(_iModelToken, _viewId) { return this.forward(arguments); }
    async getDefaultViewId(_iModelToken) { return this.forward(arguments); }
    async requestSnap(_iModelToken, _sessionId, _props) { return this.forward(arguments); }
    async cancelSnap(_iModelToken, _sessionId) { return this.forward(arguments); }
    async getGeometryContainment(_iModelToken, _props) { return this.forward(arguments); }
    async getMassProperties(_iModelToken, _props) { return this.forward(arguments); }
    async getIModelCoordinatesFromGeoCoordinates(_iModelToken, _props) { return this.forward(arguments); }
    async getGeoCoordinatesFromIModelCoordinates(_iModelToken, _props) { return this.forward(arguments); }
    async getGeometrySummary(_iModelToken, _props) { return this.forward(arguments); }
    async getTextureImage(_iModelToken, _textureLoadProps) { return this.forward(arguments); }
    async loadElementProps(_iModelToken, _elementIdentifier, _options) {
        return this.forward(arguments);
    }
}
exports.IModelReadRpcInterface = IModelReadRpcInterface;
/** The immutable name of the interface. */
IModelReadRpcInterface.interfaceName = "IModelReadRpcInterface";
/** The semantic version of the interface. */
IModelReadRpcInterface.interfaceVersion = "2.3.1";
//# sourceMappingURL=IModelReadRpcInterface.js.map