"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module RpcInterface
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IModelTileRpcInterface = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const CloudStorageTileCache_1 = require("../CloudStorageTileCache");
const RpcInterface_1 = require("../RpcInterface");
const RpcManager_1 = require("../RpcManager");
/** @public */
class IModelTileRpcInterface extends RpcInterface_1.RpcInterface {
    static getClient() { return RpcManager_1.RpcManager.getClientForInterface(IModelTileRpcInterface); }
    /*===========================================================================================
      NOTE: Any add/remove/change to the methods below requires an update of the interface version.
      NOTE: Please consult the README in this folder for the semantic versioning rules.
    ===========================================================================================*/
    /** @beta */
    async getTileCacheContainerUrl(_tokenProps, _id) {
        return this.forward(arguments);
    }
    /** Returns true if an external tile cache is configured on the backend.
     * @internal
     */
    async isUsingExternalTileCache() {
        return this.forward(arguments);
    }
    /** @internal */
    async requestTileTreeProps(_tokenProps, _id) { return this.forward(arguments); }
    /** @deprecated Use generateTileContent.
     * @internal
     */
    async requestTileContent(iModelToken, treeId, contentId, isCanceled, guid) {
        const cached = await IModelTileRpcInterface.checkCache(iModelToken, treeId, contentId, guid);
        if (undefined === cached && undefined !== isCanceled && isCanceled())
            throw new bentleyjs_core_1.AbandonedError();
        return cached || this.forward(arguments);
    }
    /** Ask the backend to generate content for the specified tile. This function, unlike the deprecated `requestTileContent`, does not check the cloud storage tile cache -
     * Use `CloudStorageTileCache.retrieve` for that.
     * @internal
     */
    async generateTileContent(_rpcProps, _treeId, _contentId, _guid) {
        return this.forward(arguments);
    }
    /** @internal */
    async queryVersionInfo() {
        return this.forward(arguments);
    }
    /** This is a temporary workaround for folks developing authoring applications, to be removed when proper support for such applications is introduced.
     * Given a set of model Ids, it purges any associated tile tree state on the back-end so that the next request for the tile tree or content will recreate that state.
     * Invoked after a modification is made to the model(s).
     * If no array of model Ids is supplied, it purges *all* tile trees, which can be quite inefficient.
     * @internal
     */
    async purgeTileTrees(_tokenProps, _modelIds) { return this.forward(arguments); }
    static async checkCache(tokenProps, treeId, contentId, guid) {
        return CloudStorageTileCache_1.CloudStorageTileCache.getCache().retrieve({ tokenProps, treeId, contentId, guid });
    }
    /** Requests graphics for a single element in "iMdl" format.
     * @returns graphics in iMdl format, or `undefined` if the element's geometry produced no graphics or the request was canceled before completion.
     * @throws IModelError on bad request (nonexistent element, duplicate request Id, etc).
     * @internal
     */
    async requestElementGraphics(_rpcProps, _request) {
        return this.forward(arguments);
    }
}
exports.IModelTileRpcInterface = IModelTileRpcInterface;
/** The immutable name of the interface. */
IModelTileRpcInterface.interfaceName = "IModelTileRpcInterface";
/** The semantic version of the interface. */
IModelTileRpcInterface.interfaceVersion = "2.3.0";
//# sourceMappingURL=IModelTileRpcInterface.js.map