/** @packageDocumentation
 * @module RpcInterface
 */
import { DbOpcode, GuidString, Id64Array, Id64String, IModelStatus } from "@bentley/bentleyjs-core";
import { LockLevel } from "@bentley/imodelhub-client";
import { ChangesetId } from "../ChangesetProps";
import { CodeProps } from "../Code";
import { AxisAlignedBox3dProps } from "../geometry/Placement";
import { IModelConnectionProps, IModelRpcOpenProps, IModelRpcProps } from "../IModel";
import { RpcInterface } from "../RpcInterface";
import { SubCategoryAppearance } from "../SubCategoryAppearance";
import { RpcRoutingToken } from "./core/RpcRoutingToken";
/** The RPC interface for writing to an iModel.
 * All operations require read+write access.
 * This interface is not normally used directly. See IModelConnection for higher-level and more convenient API for accessing iModels from a frontend.
 * @internal
 * @deprecated use IPC for writing to iModels
 */
export declare abstract class IModelWriteRpcInterface extends RpcInterface {
    /** Returns the IModelWriteRpcInterface client instance for the frontend. */
    static getClient(): IModelWriteRpcInterface;
    /** Returns the IModelWriteRpcInterface client instance for a custom RPC routing configuration. */
    static getClientForRouting(token: RpcRoutingToken): IModelWriteRpcInterface;
    /** The immutable name of the interface. */
    static readonly interfaceName = "IModelWriteRpcInterface";
    /** The version of the interface. */
    static interfaceVersion: string;
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    openForWrite(_iModelToken: IModelRpcOpenProps): Promise<IModelConnectionProps>;
    saveChanges(_iModelToken: IModelRpcProps, _description?: string): Promise<void>;
    hasUnsavedChanges(_iModelToken: IModelRpcProps): Promise<boolean>;
    hasPendingTxns(_iModelToken: IModelRpcProps): Promise<boolean>;
    updateProjectExtents(_iModelToken: IModelRpcProps, _newExtents: AxisAlignedBox3dProps): Promise<void>;
    saveThumbnail(_iModelToken: IModelRpcProps, _val: Uint8Array): Promise<void>;
    requestResources(_tokenProps: IModelRpcProps, _elementIds: Id64Array, _modelIds: Id64Array, _opcode: DbOpcode): Promise<void>;
    doConcurrencyControlRequest(_tokenProps: IModelRpcProps): Promise<void>;
    lockModel(_tokenProps: IModelRpcProps, _modelId: Id64String, _level: LockLevel): Promise<void>;
    synchConcurrencyControlResourcesCache(_tokenProps: IModelRpcProps): Promise<void>;
    /**
     * @deprecated Use [[IModelWriteRpcInterface.pullAndMergeChanges]] and [[IModelWriteRpcInterface.pushChanges]] instead
     */
    pullMergePush(_tokenProps: IModelRpcProps, _comment: string, _doPush: boolean): Promise<GuidString>;
    /**
     * @deprecated The parent change set id is always maintained in the IModelConnection
     */
    getParentChangeset(_iModelToken: IModelRpcProps): Promise<ChangesetId>;
    pullAndMergeChanges(_tokenProps: IModelRpcProps): Promise<IModelConnectionProps>;
    pushChanges(_tokenProps: IModelRpcProps, _description: string): Promise<IModelConnectionProps>;
    /** @deprecated monitor BriefcaseTxns events. */
    getModelsAffectedByWrites(_tokenProps: IModelRpcProps): Promise<Id64String[]>;
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    deleteElements(_tokenProps: IModelRpcProps, _ids: Id64Array): Promise<void>;
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    createAndInsertPhysicalModel(_tokenProps: IModelRpcProps, _newModelCode: CodeProps, _privateModel: boolean): Promise<Id64String>;
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    createAndInsertSpatialCategory(_tokenProps: IModelRpcProps, _scopeModelId: Id64String, _categoryName: string, _appearance: SubCategoryAppearance.Props): Promise<Id64String>;
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    undoRedo(_rpc: IModelRpcProps, _undo: boolean): Promise<IModelStatus>;
}
//# sourceMappingURL=IModelWriteRpcInterface.d.ts.map