"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module RpcInterface
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IModelWriteRpcInterface = void 0;
const RpcInterface_1 = require("../RpcInterface");
const RpcManager_1 = require("../RpcManager");
/* eslint-disable deprecation/deprecation */
/** The RPC interface for writing to an iModel.
 * All operations require read+write access.
 * This interface is not normally used directly. See IModelConnection for higher-level and more convenient API for accessing iModels from a frontend.
 * @internal
 * @deprecated use IPC for writing to iModels
 */
class IModelWriteRpcInterface extends RpcInterface_1.RpcInterface {
    /** Returns the IModelWriteRpcInterface client instance for the frontend. */
    static getClient() { return RpcManager_1.RpcManager.getClientForInterface(IModelWriteRpcInterface); }
    /** Returns the IModelWriteRpcInterface client instance for a custom RPC routing configuration. */
    static getClientForRouting(token) { return RpcManager_1.RpcManager.getClientForInterface(IModelWriteRpcInterface, token); }
    /*===========================================================================================
        NOTE: Any add/remove/change to the methods below requires an update of the interface version.
        NOTE: Please consult the README in this folder for the semantic versioning rules.
    ===========================================================================================*/
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    async openForWrite(_iModelToken) { return this.forward(arguments); }
    async saveChanges(_iModelToken, _description) { return this.forward(arguments); }
    async hasUnsavedChanges(_iModelToken) { return this.forward(arguments); }
    async hasPendingTxns(_iModelToken) { return this.forward(arguments); }
    async updateProjectExtents(_iModelToken, _newExtents) { return this.forward(arguments); }
    async saveThumbnail(_iModelToken, _val) { return this.forward(arguments); }
    async requestResources(_tokenProps, _elementIds, _modelIds, _opcode) { return this.forward(arguments); }
    async doConcurrencyControlRequest(_tokenProps) { return this.forward(arguments); }
    async lockModel(_tokenProps, _modelId, _level) { return this.forward(arguments); }
    async synchConcurrencyControlResourcesCache(_tokenProps) { return this.forward(arguments); }
    /**
     * @deprecated Use [[IModelWriteRpcInterface.pullAndMergeChanges]] and [[IModelWriteRpcInterface.pushChanges]] instead
     */
    async pullMergePush(_tokenProps, _comment, _doPush) { return this.forward(arguments); }
    /**
     * @deprecated The parent change set id is always maintained in the IModelConnection
     */
    async getParentChangeset(_iModelToken) { return this.forward(arguments); }
    async pullAndMergeChanges(_tokenProps) { return this.forward(arguments); }
    async pushChanges(_tokenProps, _description) { return this.forward(arguments); }
    /** @deprecated monitor BriefcaseTxns events. */
    async getModelsAffectedByWrites(_tokenProps) { return []; }
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    async deleteElements(_tokenProps, _ids) { return this.forward(arguments); }
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    async createAndInsertPhysicalModel(_tokenProps, _newModelCode, _privateModel) { return this.forward(arguments); }
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    async createAndInsertSpatialCategory(_tokenProps, _scopeModelId, _categoryName, _appearance) { return this.forward(arguments); }
    /** @deprecated use BriefcaseConnection with IpcHost/IpcApp */
    async undoRedo(_rpc, _undo) {
        return this.forward(arguments);
    }
}
exports.IModelWriteRpcInterface = IModelWriteRpcInterface;
/** The immutable name of the interface. */
IModelWriteRpcInterface.interfaceName = "IModelWriteRpcInterface";
/** The version of the interface. */
IModelWriteRpcInterface.interfaceVersion = "0.5.2";
//# sourceMappingURL=IModelWriteRpcInterface.js.map