/** @packageDocumentation
 * @module RpcInterface
 */
/** Describes available options for RPC response caching.
 * @public
 */
export declare enum RpcResponseCacheControl {
    None = 0,
    Immutable = 1
}
/** RPC protocol event types.
 * @public
 */
export declare enum RpcProtocolEvent {
    RequestCreated = 0,
    ResponseLoaded = 1,
    ResponseLoading = 2,
    ConnectionErrorReceived = 3,
    UnknownErrorReceived = 4,
    BackendErrorReceived = 5,
    ConnectionAborted = 6,
    RequestReceived = 7,
    BackendResponseCreated = 8,
    BackendReportedPending = 9,
    BackendReportedNotFound = 10,
    BackendErrorOccurred = 11,
    BackendReportedNoContent = 12
}
/** The status of an RPC operation request.
 * @public
 */
export declare enum RpcRequestStatus {
    Unknown = 0,
    Created = 1,
    Submitted = 2,
    Pending = 3,
    Resolved = 4,
    Rejected = 5,
    Disposed = 6,
    NotFound = 7,
    Cancelled = 8,
    NoContent = 9,
    BadGateway = 10,
    ServiceUnavailable = 11,
    GatewayTimeout = 12
}
/** @public */
export declare namespace RpcRequestStatus {
    function isTransientError(status: RpcRequestStatus): boolean;
}
/** RPC request event types.
 * @public
 */
export declare enum RpcRequestEvent {
    StatusChanged = 0,
    PendingUpdateReceived = 1,
    TransientErrorReceived = 2
}
/** RPC content types.
 * @public
 */
export declare enum RpcContentType {
    Unknown = 0,
    Text = 1,
    Binary = 2,
    Multipart = 3,
    Stream = 4
}
/** Endpoints for RPC protocols.
 * @public
 */
export declare enum RpcEndpoint {
    Frontend = 0,
    Backend = 1
}
/** @internal */
export declare const WEB_RPC_CONSTANTS: {
    CONTENT: string;
    TEXT: string;
    ANY_TEXT: string;
    BINARY: string;
    MULTIPART: string;
};
//# sourceMappingURL=RpcConstants.d.ts.map