/** @packageDocumentation
 * @module RpcInterface
 */
/// <reference types="node" />
import { Readable } from "stream";
import { RpcProtocol } from "./RpcProtocol";
/** @internal */
export interface MarshalingBinaryMarker {
    isBinary: true;
    index: number;
    size: number;
    chunks: number;
}
/** @internal */
export declare namespace MarshalingBinaryMarker {
    function createDefault(): MarshalingBinaryMarker;
}
/** @public */
export interface RpcSerializedValue {
    objects: string;
    data: Uint8Array[];
    chunks?: number;
    stream?: Readable;
}
/** @public */
export declare namespace RpcSerializedValue {
    function create(objects?: string, data?: Uint8Array[]): RpcSerializedValue;
}
/** @internal */
export declare class RpcMarshaling {
    private constructor();
    /** Serializes a value. */
    static serialize(protocol: RpcProtocol | undefined, value: any): Promise<RpcSerializedValue>;
    /** Deserializes a value. */
    static deserialize(protocol: RpcProtocol | undefined, value: RpcSerializedValue): any;
}
//# sourceMappingURL=RpcMarshaling.d.ts.map