/** @packageDocumentation
 * @module RpcInterface
 */
/// <reference types="node" />
import { Readable } from "stream";
import { RpcSerializedValue } from "../core/RpcMarshaling";
import { HttpServerRequest } from "../web/WebAppRpcProtocol";
/** @internal */
export interface FormDataCommon {
    append(name: string, value: string | Blob | Buffer, fileName?: string): void;
}
/** @internal */
export interface ReadableFormData extends Readable {
    getHeaders(): {
        [key: string]: any;
    };
}
/** Support for transporting RPC values using the HTTP multipart content type.
 * @internal
 */
export declare class RpcMultipart {
    /** Creates a multipart form object for an RPC value. */
    static createForm(value: RpcSerializedValue): FormData;
    /** Creates a multipart stream for an RPC value. */
    static createStream(_value: RpcSerializedValue): ReadableFormData;
    /** Obtains the RPC value from a multipart HTTP request. */
    static parseRequest(_req: HttpServerRequest): Promise<RpcSerializedValue>;
    /** @internal */
    static writeValueToForm(form: FormDataCommon, value: RpcSerializedValue): void;
}
//# sourceMappingURL=RpcMultipart.d.ts.map