"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module RpcInterface
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RpcMultipart = void 0;
const IModelError_1 = require("../../IModelError");
/** Support for transporting RPC values using the HTTP multipart content type.
 * @internal
 */
class RpcMultipart {
    /** Creates a multipart form object for an RPC value. */
    static createForm(value) {
        const form = new FormData();
        RpcMultipart.writeValueToForm(form, value);
        return form;
    }
    /** Creates a multipart stream for an RPC value. */
    static createStream(_value) {
        throw new IModelError_1.IModelError(IModelError_1.BentleyStatus.ERROR, "Not implemented.");
    }
    /** Obtains the RPC value from a multipart HTTP request. */
    static async parseRequest(_req) {
        throw new IModelError_1.IModelError(IModelError_1.BentleyStatus.ERROR, "Not implemented.");
    }
    /** @internal */
    static writeValueToForm(form, value) {
        form.append("objects", value.objects);
        for (let i = 0; i !== value.data.length; ++i) {
            if (typeof (Blob) !== "undefined") {
                form.append(`data-${i}`, new Blob([value.data[i]], { type: "application/octet-stream" }));
            }
            else {
                const buf = value.data[i];
                form.append(`data-${i}`, Buffer.from(buf.buffer, buf.byteOffset, buf.byteLength));
            }
        }
    }
}
exports.RpcMultipart = RpcMultipart;
//# sourceMappingURL=RpcMultipart.js.map