"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Tile
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.I3dmHeader = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const TileIO_1 = require("./TileIO");
/** Header preceding tile content in [i3dm](https://github.com/AnalyticalGraphicsInc/3d-tiles/tree/master/specification/TileFormats/Instanced3DModel) format.
 * @internal
 */
class I3dmHeader extends TileIO_1.TileHeader {
    constructor(stream) {
        super(stream);
        this.length = stream.nextUint32;
        this.featureTableJsonLength = stream.nextUint32;
        this.featureTableBinaryLength = stream.nextUint32;
        this.batchTableJsonLength = stream.nextUint32;
        this.batchTableBinaryLength = stream.nextUint32;
        this.gltfVersion = stream.nextUint32;
        this.featureTableJsonPosition = stream.curPos;
        stream.advance(this.featureTableJsonLength);
        stream.advance(this.featureTableBinaryLength);
        if (0 !== this.batchTableJsonLength) {
            const batchStrData = stream.nextBytes(this.batchTableJsonLength);
            const batchStr = bentleyjs_core_1.utf8ToString(batchStrData);
            if (batchStr)
                this.batchTableJson = JSON.parse(batchStr);
        }
        stream.advance(this.batchTableBinaryLength);
        if (stream.isPastTheEnd)
            this.invalidate();
    }
    get isValid() { return TileIO_1.TileFormat.I3dm === this.format; }
}
exports.I3dmHeader = I3dmHeader;
//# sourceMappingURL=I3dmTileIO.js.map